@@ -2,6 +2,7 @@
 
 #include "inode.h"
 #include "imodule.h"
+#include "imap.h"
 
 namespace map 
 { 
@@ -12,45 +13,40 @@ namespace map
 class IMapResource
 {
 public:
-	class Observer {
-	public:
-	    virtual ~Observer() {}
-		virtual void onResourceRealise() = 0;
-		virtual void onResourceUnrealise() = 0;
-	};
-
 	virtual ~IMapResource() {}
 
 	// Renames this map resource to the new path
 	virtual void rename(const std::string& fullPath) = 0;
 
 	virtual bool load() = 0;
+
+	/**
+	* Save this resource
+	*
+	* It's possible to pass a mapformat to be used for saving. If the map
+	* format argument is omitted, the format corresponding to the current
+	* game type is used.
+	*
+	* @returns
+	* true if the resource was saved, false otherwise.
+	*/
 	virtual bool save(const map::MapFormatPtr& mapFormat = map::MapFormatPtr()) = 0;
 
-	// Reloads the map file from disk
-	virtual void reload() = 0;
-
-	virtual scene::INodePtr getNode() = 0;
-	virtual void setNode(scene::INodePtr node) = 0;
-
-	virtual void addObserver(Observer& observer) = 0;
-	virtual void removeObserver(Observer& observer) = 0;
-
-	virtual void realise() = 0;
-	virtual void unrealise() = 0;
+    virtual scene::IMapRootNodePtr getNode() = 0;
+    virtual void setNode(const scene::IMapRootNodePtr& node) = 0;
 };
 typedef std::shared_ptr<IMapResource> IMapResourcePtr;
 
-const std::string MODULE_MAPRESOURCEMANAGER("MapResourceManager");
+const char* const MODULE_MAPRESOURCEMANAGER("MapResourceManager");
 
 class IMapResourceManager :
 	public RegisterableModule
 {
 public:
 	/**
-	 * Capture a named model resource, and return a pointer to it.
+	 * Load the named map resource from VFS or from a physical path.
 	 */
-	virtual IMapResourcePtr capture(const std::string& path) = 0;
+	virtual IMapResourcePtr loadFromPath(const std::string& path) = 0;
 };
 
 inline IMapResourceManager& GlobalMapResourceManager() {
