@@ -3,6 +3,7 @@
 #include "imodule.h"
 #include "imodel.h"
 #include "inode.h"
+#include <sigc++/signal.h>
 
 namespace model 
 {
@@ -32,8 +33,14 @@ public:
 	 */
 	virtual IModelPtr getModel(const std::string& modelPath) = 0;
 
+	// Clears a specific model from the cache
+	virtual void removeModel(const std::string& modelPath) = 0;
+
 	// Clears the modelcache
 	virtual void clear() = 0;
+
+	/// Signal emitted after models are reloaded
+	virtual sigc::signal<void> signal_modelsReloaded() = 0;
 };
 
 } // namespace model
