@@ -1,7 +1,10 @@
 #pragma once
 
 #include "imodule.h"
-#include <boost/python/object_fwd.hpp>
+
+// Forward-declare the stuff in <pybind11/pybind11.h>
+namespace pybind11 { class module; class dict; }
+namespace py = pybind11;
 
 namespace script
 {
@@ -22,16 +25,17 @@ class IScriptInterface
 {
 public:
     virtual ~IScriptInterface() {}
+
 	/**
-	 * This method gets invoked by the Scripting System to let this class
-	 * add its interface to the Python context.
-	 */
-	virtual void registerInterface(boost::python::object& nspace) = 0;
+	* This method is called by the Scripting System to let this class
+	* add its objects to the Python context.
+	*/
+	virtual void registerInterface(py::module& scope, py::dict& globals) = 0;
 };
 typedef std::shared_ptr<IScriptInterface> IScriptInterfacePtr;
 
 /**
- * DarkRadiant's Scripting System, based on boost::python. It's possible
+ * DarkRadiant's Scripting System, based on pybind11. It's possible
  * to expose additional interfaces by using the addInterface() method.
  */
 class IScriptingSystem :
@@ -61,10 +65,11 @@ public:
 typedef std::shared_ptr<IScriptingSystem> IScriptingSystemPtr;
 
 // String identifier for the script module
-const std::string MODULE_SCRIPTING_SYSTEM("ScriptingSystem");
+const char* const MODULE_SCRIPTING_SYSTEM("ScriptingSystem");
 
 // This is the accessor for the scripting system
-inline IScriptingSystem& GlobalScriptingSystem() {
+inline IScriptingSystem& GlobalScriptingSystem()
+{
 	// Cache the reference locally
 	static IScriptingSystem& _scriptingSystem(
 		*std::static_pointer_cast<IScriptingSystem>(
