@@ -16,20 +16,17 @@ print(eclass.getAttribute('editor_usage').getValue())
 if not eclass.isNull():
 	shooter = GlobalEntityCreator.createEntity(eclass)
 
-modelDef = GlobalEntityClassManager.findModel('builderforger')
-print('ModelDef mesh for builderforger = ' + modelDef.mesh)
+modelDef = GlobalEntityClassManager.findModel('tdm_ai_citywatch')
+print('ModelDef mesh for tdm_ai_citywatch = ' + modelDef.mesh)
 
 # Test iterating over C++ std::map
-#for anim in modelDef.anims:
-#	print(anim.key())
-#	print(' = ')
-#	print(anim.data())
-#	print('')
+for anim in modelDef.anims:
+	print(anim + " = " + modelDef.anims[anim])
 
 # Test implementing a eclass visitor interface
 #class TestVisitor(EntityClassVisitor) :
 #	def visit(self, eclass):
-#		print eclass.getAttribute('editor_usage').getValue()
+#		print(eclass.getAttribute('editor_usage').getValue())
 
 #eclassVisitor = TestVisitor()
 #GlobalEntityClassManager.forEachEntityClass(eclassVisitor)
@@ -93,6 +90,8 @@ class Walker(SelectionVisitor) :
 visitor = Walker()
 GlobalSelectionSystem.foreachSelected(visitor)
 
+print('Map name is ' + GlobalMap.getMapName())
+
 # Try to find the map's worldspawn
 worldspawn = GlobalMap.getWorldSpawn()
 
@@ -121,7 +120,7 @@ if not worldspawn.isNull():
 	keyvalues = worldspawnent.getKeyValuePairs('t')
 
 	for kv in keyvalues:
-		print('Keyvalue ' + kv.first + ' = ' + kv.second)
+		print('Keyvalue ' + kv[0] + ' = ' + kv[1])
 
 # Test the commandsystem
 GlobalCommandSystem.execute('texscale "0 0.1"')
@@ -139,14 +138,14 @@ for path in vfsPaths:
 	print(path)
 
 # Test FileSystem (VFS)
-#class TestFileVisitor(FileVisitor) :
-#	def visit(self, filename):
-#		print('Found file: ' + filename)
-#
-#filevisitor = TestFileVisitor()
-#GlobalFileSystem.forEachFile('skins/', 'skin', filevisitor, 99)
+class TestFileVisitor(FileVisitor) :
+	def visit(self, filename):
+		print('Found file: ' + filename)
 
-filecontents = GlobalFileSystem.readTextFile('skins/tdm_ai_elemental_fire.skin');
+filevisitor = TestFileVisitor()
+GlobalFileSystem.forEachFile('skins/', 'skin', filevisitor, 99)
+
+filecontents = GlobalFileSystem.readTextFile('skins/tdm_ai_guard_citywatch.skin');
 print(filecontents)
 
 # Test the Grid Interface
@@ -214,6 +213,10 @@ GlobalSceneGraph.root().traverse(walker)
 #	modelskin = GlobalModelSkinCache.capture(skin)
 #	print('Skin found: ' + modelskin.getName())
 
+v = Vector3(6,6,6)
+v += Vector3(10,10,10)
+print(v)
+
 # Test patch manipulation
 class PatchManipulator(SceneNodeVisitor) :
 	def pre(self, node):
@@ -262,3 +265,45 @@ if selSet.empty():
 
 print('')
 
+soundshader = GlobalSoundManager.getSoundShader('tdm_ai_lady_alertdown_to_idle')
+
+if not soundshader.isNull():
+	print('Name of this sound shader: ' + soundshader.getName())
+
+	radii = soundshader.getRadii()
+
+	print('Minimum radius in meters: ' + str(radii.getMin(1)))
+	print('Maximum radius in meters: ' + str(radii.getMax(1)))
+
+	fileList = soundshader.getSoundFileList()
+	for i in range(0, len(fileList)):
+		print(' Sound file used by this shader: ' + fileList[i])
+
+	if (len(fileList) > 0):
+		GlobalSoundManager.playSound(fileList[0])
+
+# Test SelectionGroup interface
+group = GlobalSelectionGroupManager.createSelectionGroup()
+
+print('Created group with ID: ' + str(group.getId()))
+
+# Test traversing the current selection
+class GroupAdder(SelectionVisitor) :
+	def visit(self, node):
+		group.addNode(node)
+
+visitor = Walker()
+GlobalSelectionSystem.foreachSelected(visitor)
+
+print('The group contains now ' + str(group.size()) + ' items')
+
+# Deselect the group
+GlobalSelectionGroupManager.setGroupSelected(group.getId(), 0)
+
+# List nodes in this group
+class SelectionGroupWalker(SelectionGroupVisitor) :
+	def visit(self, node):
+		print('Group Member: ' + node.getNodeType())
+
+gropWalker = SelectionGroupWalker();
+group.foreachNode(gropWalker)
\ No newline at end of file
