@@ -2,7 +2,6 @@
 
 #include "iundo.h"
 #include "mapfile.h"
-#include "warnings.h"
 #include <functional>
 #include "BasicUndoMemento.h"
 
@@ -18,41 +17,37 @@ class ObservedUndoable :
 	Copyable& _object;
 	ImportCallback _importCallback;
 	IUndoStateSaver* _undoStateSaver;
-	IMapFileChangeTracker* _map;
+    IMapFileChangeTracker* _changeTracker;
+
 public:
 	ObservedUndoable<Copyable>(Copyable& object, const ImportCallback& importCallback) :
 		_object(object), 
 		_importCallback(importCallback), 
-		_undoStateSaver(NULL), 
-		_map(NULL)
+        _undoStateSaver(nullptr),
+        _changeTracker(nullptr)
 	{}
 
-	IMapFileChangeTracker* map()
+    IMapFileChangeTracker& getUndoChangeTracker()
+    {
+        return *_changeTracker;
+    }
+
+	void connectUndoSystem(IMapFileChangeTracker& changeTracker)
 	{
-		return _map;
+        _changeTracker = &changeTracker;
+		_undoStateSaver = GlobalUndoSystem().getStateSaver(*this, changeTracker);
 	}
 
-	void onInsertIntoScene(IMapFileChangeTracker* map)
+    void disconnectUndoSystem(IMapFileChangeTracker& map)
 	{
-		_map = map;
-		_undoStateSaver = GlobalUndoSystem().getStateSaver(*this);
-	}
-
-	void onRemoveFromScene(IMapFileChangeTracker* map)
-	{
-		_map = NULL;
-		_undoStateSaver = NULL;
+        _undoStateSaver = nullptr;
+        _changeTracker = nullptr;
 		GlobalUndoSystem().releaseStateSaver(*this);
 	}
 
 	void save()
 	{
-		if (_map != NULL)
-		{
-			_map->changed();
-		}
-
-		if (_undoStateSaver != NULL)
+		if (_undoStateSaver != nullptr)
 		{
 			_undoStateSaver->save(*this);
 		}
