@@ -10,6 +10,7 @@ Ernie Wright  17 Sep 00
 
 #include "../picointernal.h"
 #include "lwo2.h"
+#include <stdint.h>
 
 /* disable warnings */
 #ifdef WIN32
@@ -100,7 +101,7 @@ parameters.
 
 static int add_tvel( float pos[], float vel[], lwEnvelope **elist, int *nenvs )
 {
-   lwEnvelope *env;
+   lwEnvelope *env = NULL;
    lwKey *key0, *key1;
    int i;
 
@@ -218,7 +219,7 @@ lwSurface *lwGetSurface5( picoMemStream_t *fp, int cksize, lwObject *obj )
    /* remember where we started */
 
    set_flen( 0 );
-   pos = _pico_memstream_tell( fp );
+   pos = (int)_pico_memstream_tell( fp );
 
    /* name */
 
@@ -550,7 +551,7 @@ int lwGetPolygons5( picoMemStream_t *fp, int cksize, lwPolygonList *plist, int p
          bp += 2;
       }
       j -= 1;
-      pp->surf = ( lwSurface * ) j;
+      pp->surf = ( lwSurface * ) (intptr_t) j;
 
       pp++;
       pv += nv;
@@ -691,7 +692,7 @@ lwObject *lwGetObject5( char *filename, picoMemStream_t *fp, unsigned int *failI
 Fail:
    if ( failID ) *failID = id;
    if ( fp ) {
-      if ( failpos ) *failpos = _pico_memstream_tell( fp );
+      if ( failpos ) *failpos = (int)_pico_memstream_tell( fp );
    }
    lwFreeObject( object );
    return NULL;
@@ -720,6 +721,7 @@ int lwValidateObject5( char *filename, picoMemStream_t *fp, unsigned int *failID
 
    if ( id != ID_FORM || type != ID_LWOB ) {
       if ( failpos ) *failpos = 12;
+      formsize++; /* silence compiler warning about unused variable */
       return PICO_PMV_ERROR_IDENT;
    }
 
