@@ -46,6 +46,7 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 /* dependencies */
 #include <string.h>
 #include <stdlib.h>
+#include <stdint.h>
 #include "picointernal.h"
 
 
@@ -351,7 +352,7 @@ void _pico_expand_bounds( picoVec3_t p, picoVec3_t mins, picoVec3_t maxs )
 	int i;
 	for (i=0; i<3; i++)
 	{
-		float value = p[i];
+		double value = p[i];
 		if (value < mins[i]) mins[i] = value;
 		if (value > maxs[i]) maxs[i] = value;
 	}
@@ -970,7 +971,7 @@ int _pico_parse_check( picoParser_t *p, int allowLFs, char *str )
 		return 0;
 	if (!strcmp(p->token,str))
 		return 1;
-		return 0;
+    return 0;
 }
 
 int _pico_parse_checki( picoParser_t *p, int allowLFs, char *str )
@@ -979,7 +980,7 @@ int _pico_parse_checki( picoParser_t *p, int allowLFs, char *str )
 		return 0;
 	if (!_pico_stricmp(p->token,str))
 		return 1;
-		return 0;
+    return 0;
 }
 
 int _pico_parse_int( picoParser_t *p, int *out )
@@ -1293,7 +1294,7 @@ void _pico_free_memstream( picoMemStream_t *s )
 /* _pico_memstream_read:
  *  reads data from a pico memorystream into a buffer.
  */
-int _pico_memstream_read( picoMemStream_t *s, void *buffer, int len )
+int _pico_memstream_read( picoMemStream_t *s, void *buffer, size_t len )
 {
 	int ret = 1;
 
@@ -1337,7 +1338,7 @@ int _pico_memstream_getc( picoMemStream_t *s )
  */
 int _pico_memstream_seek( picoMemStream_t *s, long offset, int origin )
 {
-	int overflow;
+	intptr_t overflow;
 
 	/* sanity check */
 	if (s == NULL)
@@ -1350,7 +1351,7 @@ int _pico_memstream_seek( picoMemStream_t *s, long offset, int origin )
 		if (overflow > 0)
 		{
 			s->curPos = s->buffer + s->bufSize;
-			return offset - overflow;
+			return (int)(offset - overflow);
 		}
 		return 0;
 	}
@@ -1361,7 +1362,7 @@ int _pico_memstream_seek( picoMemStream_t *s, long offset, int origin )
 		if (overflow > 0)
 		{
 			s->curPos = s->buffer + s->bufSize;
-			return offset - overflow;
+			return (int)(offset - overflow);
 		}
 		return 0;
 	}
@@ -1372,7 +1373,7 @@ int _pico_memstream_seek( picoMemStream_t *s, long offset, int origin )
 		if (overflow > 0)
 		{
 			s->curPos = s->buffer;
-			return offset - overflow;
+			return (int)(offset - overflow);
 		}
 		return 0;
 	}
@@ -1389,5 +1390,5 @@ long _pico_memstream_tell( picoMemStream_t *s )
 	if (s == NULL)
 		return -1;
 
-	return s->curPos - s->buffer;
+	return (long)(s->curPos - s->buffer);
 }
