@@ -1404,9 +1404,27 @@ int PicoGetHashTableSize( void )
 #define HASH_NORMAL_EPSILON					0.02f
 #endif
 
+// djb2 Hash function adapted from http://www.cse.yorku.ca/~oz/hash.html
+unsigned int calculateHash(unsigned char* str, size_t len)
+{
+	unsigned int hash = 5381;
+	int c;
+	size_t i;
+
+    for (i = 0; i < len; ++i)
+    {
+        c = str[i];
+        hash = ((hash << 5) + hash) + c; /* hash * 33 + c */
+    }
+
+	return hash;
+}
+
 unsigned int PicoVertexCoordGenerateHash( picoVec3_t xyz )
 {
 	unsigned int hash = 0;
+	// Allocate bytes for the 3 doubles
+	unsigned char buffer[sizeof(picoVec3_t)];
 
 #ifndef HASH_USE_EPSILON
 	hash += ~(*((unsigned int*) &xyz[ 0 ]) << 15);
@@ -1423,12 +1441,21 @@ unsigned int PicoVertexCoordGenerateHash( picoVec3_t xyz )
 	xyz_epsilonspace[ 1 ] = (double)floor(xyz_epsilonspace[ 1 ]);
 	xyz_epsilonspace[ 2 ] = (double)floor(xyz_epsilonspace[ 2 ]);
 
+	/* greebo: Copy the memory occupied by the floor'ed doubles 
+	   to the unsigned char array and hash them */
+	memcpy(buffer, &xyz_epsilonspace[0], sizeof(picoVec3_t));
+
+	hash = calculateHash(buffer, sizeof(picoVec3_t));
+	
+/*  greebo: This was the previous, compiler-warning-producing code
+
 	hash += ~(*((unsigned int*) &xyz_epsilonspace[ 0 ]) << 15);
 	hash ^= (*((unsigned int*) &xyz_epsilonspace[ 0 ]) >> 10);
 	hash += (*((unsigned int*) &xyz_epsilonspace[ 1 ]) << 3);
 	hash ^= (*((unsigned int*) &xyz_epsilonspace[ 1 ]) >> 6);
 	hash += ~(*((unsigned int*) &xyz_epsilonspace[ 2 ]) << 11);
 	hash ^= (*((unsigned int*) &xyz_epsilonspace[ 2 ]) >> 16);
+*/
 #endif
 
 	//hash = hash & (HASHTABLE_SIZE-1);
@@ -1521,8 +1548,15 @@ picoVertexCombinationHash_t *PicoFindVertexCombinationInHashTable( picoVertexCom
 #endif
 
 		/* check color */
-		if( *((int*) vertexCombinationHash->vcd.color) != *((int*) color) )
+        if (vertexCombinationHash->vcd.color[0] != color[0] ||
+            vertexCombinationHash->vcd.color[1] != color[1] ||
+            vertexCombinationHash->vcd.color[2] != color[2] ||
+            vertexCombinationHash->vcd.color[3] != color[3])
+		/* greebo: Old code:
+           if( *((int*) vertexCombinationHash->vcd.color) != *((int*) color) )*/
+        {
 			continue;
+        }
 
 		/* gotcha */
 		return vertexCombinationHash;
