@@ -215,6 +215,7 @@ static void FreeObjVertexData( TObjVertexData *vertexData )
 	}
 }
 
+#if 0 // greebo: function is not called right now, comment out
 static int _obj_mtl_load( picoModel_t *model )
 {
 	picoShader_t *curShader = NULL;
@@ -477,6 +478,7 @@ static int _obj_mtl_load( picoModel_t *model )
 	/* return with success */
 	return 1;
 }
+#endif
 
 /* _obj_load:
  *  loads a wavefront obj model file.
@@ -662,7 +664,7 @@ static picoModel_t *_obj_load( PM_PARAMS_LOAD )
 			picoVec3_t normals[ 4 ];
 			picoVec2_t coords [ 4 ];
 
-			int iv [ 4 ], has_v;
+			int iv [ 4 ], has_v = 0;
 			int ivt[ 4 ], has_vt = 0;
 			int ivn[ 4 ], has_vn = 0;
 			int have_quad = 0;
