@@ -2,19 +2,19 @@
 
 #include "irender.h"
 
-#include <boost/foreach.hpp>
-
 namespace render
 {
+
 namespace lib
 {
 
 /**
  * Implementation of the LightList interface using a std::vector of pointers.
  */
-class VectorLightList
-: public LightList
+class VectorLightList : 
+	public LightList
 {
+private:
     // Vector of lights
     typedef std::vector<const RendererLight*> Lights;
     Lights _lights;
@@ -23,11 +23,13 @@ class VectorLightList
 
 public:
 
-    void addLight(const RendererLight& light) {
+    void addLight(const RendererLight& light)
+	{
         _lights.push_back(&light);
     }
 
-    void clear() {
+    void clear()
+	{
         _lights.clear();
     }
 
@@ -37,7 +39,7 @@ public:
 
     void forEachLight(const RendererLightCallback& callback) const
     {
-        BOOST_FOREACH(const RendererLight* light, _lights)
+        for (const RendererLight* light : _lights)
         {
             callback(*light);
         }
@@ -50,4 +52,5 @@ inline std::ostream& operator<< (std::ostream& os, const VectorLightList& ll)
 }
 
 }
+
 }
