@@ -76,6 +76,37 @@ void TreeView::TriggerColumnSizeEvent(const wxDataViewItem& item)
     });
 }
 
+void TreeView::ExpandTopLevelItems()
+{
+	TreeModel* model = dynamic_cast<TreeModel*>(GetModel());
+
+	if (model == nullptr) return;
+
+	// Expand the first layer
+	wxDataViewItemArray children;
+	model->GetChildren(model->GetRoot(), children);
+
+	std::for_each(children.begin(), children.end(), [&](const wxDataViewItem& item)
+	{
+		Expand(item);
+	});
+}
+
+void TreeView::ResetSortingOnAllColumns()
+{
+#if wxCHECK_VERSION(3, 1, 0) && defined(__WXMSW__ )
+	ResetAllSortColumns();
+#else
+	// We don't have ResetAllSortColumns in wxWidgets 3.0.x
+	wxDataViewColumn* col = GetSortingColumn();
+
+	if (col != nullptr)
+	{
+		col->UnsetAsSortKey();
+	}
+#endif
+}
+
 void TreeView::AddSearchColumn(const TreeModel::Column& column)
 {
 	// Only text columns are supported right now
