@@ -18,11 +18,8 @@
 
 #include <wx/artprov.h>
 
-#include <boost/format.hpp>
-#include <boost/algorithm/string/predicate.hpp>
-#include <boost/algorithm/string/case_conv.hpp>
-#include <boost/algorithm/string/classification.hpp>
-#include <boost/algorithm/string/split.hpp>
+#include <fmt/format.h>
+#include "string/predicate.h"
 
 namespace wxutil
 {
@@ -86,7 +83,7 @@ void ParticlePreview::setParticle(const std::string& name)
 {
     std::string nameClean = name;
 
-    if (boost::algorithm::ends_with(nameClean, ".prt"))
+    if (string::ends_with(nameClean, ".prt"))
     {
         nameClean = nameClean.substr(0, nameClean.length() - 4);
     }
@@ -182,9 +179,8 @@ void ParticlePreview::setupSceneGraph()
 	}
 	catch (std::runtime_error&)
 	{
-		wxutil::Messagebox::ShowError(
-			(boost::format(_("Unable to setup the preview,\n"
-			"could not find the entity class %s")) % FUNC_EMITTER_CLASS).str());
+		wxutil::Messagebox::ShowError(fmt::format(_("Unable to setup the preview,\n"
+			"could not find the entity class {0}"), FUNC_EMITTER_CLASS));
 	}
 }
 
