@@ -16,6 +16,8 @@
 #include "render/SceneRenderWalker.h"
 #include "render/NopVolumeTest.h"
 
+class wxToolBarToolBase;
+
 namespace wxutil
 {
 
@@ -56,8 +58,10 @@ private:
     void onSizeAllocate(wxSizeEvent& ev);
     void filtersChanged();
     void onRenderModeChanged(wxCommandEvent& ev);
+	void onGridButtonClick(wxCommandEvent& ev);
 
     void drawTime();
+	void drawGrid();
 
     // Called each frame by wxTimer
     void _onFrame(wxTimerEvent& ev);
@@ -81,6 +85,8 @@ private:
 
     FreezePointer _freezePointer;
 
+	bool _renderGrid;
+
 protected:
     // The backend rendersystem instance
     RenderSystemPtr _renderSystem;
@@ -117,6 +123,7 @@ protected:
 
     // The filters menu
     ui::IFilterMenuPtr _filtersMenu;
+	wxToolBarToolBase* _filterTool;
 
 protected:
     const scene::GraphPtr& getScene();
