@@ -10,7 +10,8 @@
 #include "Statement.h"
 
 #include <functional>
-#include <boost/algorithm/string/trim.hpp>
+#include "string/trim.h"
+#include "string/predicate.h"
 
 namespace cmd
 {
@@ -84,7 +85,7 @@ void CommandSystem::loadBinds() {
 		std::string statement = node.getAttributeValue("value");
 
 		// remove all whitespace from the front and the tail
-		boost::algorithm::trim(statement);
+		string::trim(statement);
 
 		// Create a new statement
 		StatementPtr st(new Statement(
@@ -221,7 +222,7 @@ void CommandSystem::addStatement(const std::string& statementName,
 {
 	// Remove all whitespace at the front and the tail
 	StatementPtr st(new Statement(
-		boost::algorithm::trim_copy(str),
+		string::trim_copy(str),
 		!saveStatementToRegistry // read-only if we should not save this statement
 	));
 
@@ -378,9 +379,11 @@ AutoCompletionInfo CommandSystem::getAutoCompletionInfo(const std::string& prefi
 
 	returnValue.prefix = prefix;
 
-	for (CommandMap::const_iterator i = _commands.begin(); i != _commands.end(); ++i) {
+	for (CommandMap::const_iterator i = _commands.begin(); i != _commands.end(); ++i)
+	{
 		// Check if the command matches the given prefix
-		if (boost::algorithm::istarts_with(i->first, prefix)) {
+		if (string::istarts_with(i->first, prefix))
+		{
 			returnValue.candidates.push_back(i->first);
 		}
 	}
