@@ -3,8 +3,8 @@
 #include "i18n.h"
 #include "string/string.h"
 
-#include <boost/format.hpp>
-#include <boost/algorithm/string/join.hpp>
+#include <fmt/format.h>
+#include "string/join.h"
 #include <regex>
 
 #include "CommandEditor.h"
@@ -229,7 +229,7 @@ void ConversationEditor::updateCommandList()
         wxutil::TreeModel::Row row = _commandStore->AddItem();
 
         row[_commandColumns.cmdNumber] = i->first;
-        row[_commandColumns.actorName] = (boost::format(_("Actor %d")) % cmd.actor).str();
+        row[_commandColumns.actorName] = fmt::format(_("Actor {0:d}"), cmd.actor);
         row[_commandColumns.sentence] = removeMarkup(cmd.getSentence());
         row[_commandColumns.wait] = cmd.waitUntilFinished ? _("yes") : _("no");
 
@@ -452,13 +452,13 @@ void ConversationEditor::onValidateActors(wxCommandEvent& ev)
 
 		if (!finder.getFoundNode())
 		{
-			errors.push_back((boost::format(_("The actor %s cannot be found in the current map.")) % i.second).str());
+			errors.push_back(fmt::format(_("The actor {0} cannot be found in the current map."), i.second));
 		}
 	}
 
 	if (!errors.empty())
 	{
-		std::string message = boost::algorithm::join(errors, "\n");
+		std::string message = string::join(errors, "\n");
 		wxutil::Messagebox::Show(_("Actors missing"), message, IDialog::MESSAGE_ERROR, this);
 	}
 	else
