@@ -13,6 +13,7 @@
 
 #include "registry/registry.h"
 #include "string/string.h"
+#include "string/convert.h"
 #include "os/file.h"
 #include "os/path.h"
 #include "i18n.h"
@@ -313,7 +314,7 @@ bool ReadableEditorDialog::initControlsFromEntity()
 		}
 		catch (XdFileChooserDialog::ImportFailedException&)
 		{
-			std::string msg = (boost::format(_("Failed to import %s.")) % _entity->getKeyValue("xdata_contents")).str();
+			std::string msg = fmt::format(_("Failed to import {0}."), _entity->getKeyValue("xdata_contents"));
 			msg += "\n";
 			msg += _("Creating a new XData definition...");
 			msg += "\n\n";
@@ -394,7 +395,7 @@ bool ReadableEditorDialog::save()
 		{
 		case XData::OpenFailed:
 			wxutil::Messagebox::ShowError(
-				(boost::format(_("Failed to open %s for saving.")) % _xdFilename).str(),
+				fmt::format(_("Failed to open {0} for saving."), _xdFilename),
 				this
 			);
 			_saveInProgress = false;
@@ -415,7 +416,7 @@ bool ReadableEditorDialog::save()
 	else if (fst == XData::OpenFailed)
 	{
 		wxutil::Messagebox::ShowError(
-			(boost::format(_("Failed to open %s for saving.")) % _xdFilename).str(),
+			fmt::format(_("Failed to open {0} for saving."), _xdFilename),
 			this
 		);
 	}
@@ -496,16 +497,16 @@ std::string ReadableEditorDialog::constructStoragePath()
 
 				while ( (compPath.compare(storagePath + newFileName) != 0) )
 				{
-					newFileName = _mapBasedFilename.substr(0, _mapBasedFilename.rfind(".")) + boost::lexical_cast<std::string>(fileIdx++) + ".xd";
+					newFileName = _mapBasedFilename.substr(0, _mapBasedFilename.rfind(".")) + string::to_string(fileIdx++) + ".xd";
 					compPath = GlobalFileSystem().findFile(XData::XDATA_DIR + newFileName);
 					if (compPath.empty())
 					{
 						wxutil::Messagebox::ShowError(
-							(boost::format(_("%s%s already exists in another path.\n\nXData will be stored in %s%s!")) %
-								XData::XDATA_DIR % 
-								_mapBasedFilename % 
-								XData::XDATA_DIR % 
-								newFileName).str(),
+							fmt::format(_("{0}{1} already exists in another path.\n\nXData will be stored in {2}{3}!"),
+								XData::XDATA_DIR,
+								_mapBasedFilename,
+								XData::XDATA_DIR,
+								newFileName),
 							this
 						);
 						break;
@@ -636,11 +637,11 @@ void ReadableEditorDialog::updateGuiView(wxWindow* parent,
 		if (_xdLoader->importDef(xDataName, xdMap, xDataPath))
 		{
 			xd = xdMap.begin()->second;
-			_guiView->setGui(xd->getGuiPage(0));
+			_guiView->setGui(GlobalGuiManager().getGui(xd->getGuiPage(0)));
 		}
 		else
 		{
-			std::string msg = (boost::format(_("Failed to import %s.")) % xDataName).str();
+			std::string msg = fmt::format(_("Failed to import {0}."), xDataName);
 			msg += "\n\n";
 			msg += _("Do you want to open the import summary?");
 
@@ -655,11 +656,11 @@ void ReadableEditorDialog::updateGuiView(wxWindow* parent,
 			return;
 		}
 
-		const gui::GuiPtr& gui = _guiView->getGui();
+		const gui::IGuiPtr& gui = _guiView->getGui();
 
 		if (gui == NULL)
 		{
-			std::string msg = (boost::format(_("Failed to load gui definition %s.")) % xd->getGuiPage(0)).str();
+			std::string msg = fmt::format(_("Failed to load gui definition {0}."), xd->getGuiPage(0));
 			msg += "\n\n";
 			msg += _("Do you want to open the import summary?");
 
@@ -697,20 +698,20 @@ void ReadableEditorDialog::updateGuiView(wxWindow* parent,
 	{
 		if (guiPath.empty())
 		{
-			_guiView->setGui(_guiEntry->GetValue().ToStdString());
+			_guiView->setGui(GlobalGuiManager().getGui(_guiEntry->GetValue().ToStdString()));
 		}
 		else
 		{
-			_guiView->setGui(guiPath);
+			_guiView->setGui(GlobalGuiManager().getGui(guiPath));
 		}
 
-		const gui::GuiPtr& gui = _guiView->getGui();
+		const gui::IGuiPtr& gui = _guiView->getGui();
 
 		if (gui == NULL)
 		{
 			std::string nameGui = guiPath.empty() ? _guiEntry->GetValue().ToStdString() : guiPath;
 
-			std::string msg = (boost::format(_("Failed to load gui definition %s.")) % nameGui).str();
+			std::string msg = fmt::format(_("Failed to load gui definition {0}."), nameGui);
 			msg += "\n\n";
 			msg += _("Do you want to open the import summary?");
 
@@ -748,7 +749,7 @@ void ReadableEditorDialog::updateGuiView(wxWindow* parent,
 	_guiView->redraw();
 }
 
-void ReadableEditorDialog::initGuiState(const gui::GuiPtr& gui)
+void ReadableEditorDialog::initGuiState(const gui::IGuiPtr& gui)
 {
     assert(gui);
 
@@ -833,7 +834,7 @@ void ReadableEditorDialog::checkXDataUniqueness()
 		// The definition already exists. Ask the user whether it should be imported. If not make a different name suggestion.
 		wxutil::Messagebox dialog(
 			_("Import definition?"),
-			(boost::format(_("The definition %s already exists. Should it be imported?")) % xdn).str(),
+			fmt::format(_("The definition {0} already exists. Should it be imported?"), xdn),
 			ui::IDialog::MESSAGE_ASK, this
 		);
 
@@ -883,8 +884,8 @@ void ReadableEditorDialog::checkXDataUniqueness()
 		_xDataNameEntry->SetValue(suggestion);
 		_xData->setName(suggestion);
 
-		message += (boost::format(_("To avoid duplicated XData definitions "
-			"the current definition has been renamed to %s.")) % suggestion).str();
+		message += fmt::format(_("To avoid duplicated XData definitions "
+			"the current definition has been renamed to {0}."), suggestion);
 
 		wxutil::Messagebox::Show(
 			_("XData has been renamed."),
@@ -1150,7 +1151,7 @@ void ReadableEditorDialog::checkGuiLayout()
 
 	std::string msg;
 
-	gui::GuiType type = gui::GuiManager::Instance().getGuiType(guiName);
+	gui::GuiType type = GlobalGuiManager().getGuiType(guiName);
 
 	switch (type)
 	{
@@ -1263,7 +1264,7 @@ void ReadableEditorDialog::showXdImportSummary()
 
 void ReadableEditorDialog::showGuiImportSummary()
 {
-	XData::StringList errors = gui::GuiManager::Instance().getErrorList();
+	XData::StringList errors = GlobalGuiManager().getErrorList();
 	if (errors.empty())
 	{
 		wxutil::Messagebox::ShowError(_("No import summary available. Browse Gui Definitions first."), this);
@@ -1396,7 +1397,7 @@ void ReadableEditorDialog::onBrowseXd(wxCommandEvent& ev)
 	}
 	catch (XdFileChooserDialog::ImportFailedException&)
 	{
-		std::string msg = (boost::format(_("Failed to import %s.")) % res).str();
+		std::string msg = fmt::format(_("Failed to import {0}."), res);
 		msg += "\n\n";
 		msg += _("Do you want to open the import summary?");
 
@@ -1570,7 +1571,7 @@ void ReadableEditorDialog::showDuplicateDefinitions()
 
 		occ += it->second[it->second.size() - 1];
 
-		out += (boost::format(_("%s has been defined in:")) % it->first).str();
+		out += fmt::format(_("{0} has been defined in:"), it->first);
 		out +="\n\t";
 		out += occ;
 		out += ".\n\n";
