@@ -33,7 +33,7 @@ class ReadableEditorDialog :
 	private wxutil::XmlResourceBasedWidget
 {
 private:
-	gui::GuiView* _guiView;
+	gui::ReadableGuiView* _guiView;
 
 	// The entity we're working with
 	Entity* _entity;
@@ -116,7 +116,7 @@ public:
 					   const std::string& xDataPath = "");
 
     // Sets some GUI state variables needed for rendering and sets the time for script execution
-    void initGuiState(const gui::GuiPtr& gui);
+    void initGuiState(const gui::IGuiPtr& gui);
 
 	// shows the XData import Summary
 	void showXdImportSummary();
