@@ -1,5 +1,8 @@
 #include "ReadableGuiView.h"
 
+#include "math/Vector4.h"
+#include "gui/GuiWindowDef.h"
+
 namespace gui
 {
 
@@ -28,7 +31,7 @@ void ReadableGuiView::setGLViewPort()
 	glViewport(0, 0, static_cast<GLsizei>(width), static_cast<GLsizei>(height));
 }
 
-void ReadableGuiView::setGui(const GuiPtr& gui)
+void ReadableGuiView::setGui(const IGuiPtr& gui)
 {
 	// Call the base class first
 	GuiView::setGui(gui);
@@ -38,7 +41,7 @@ void ReadableGuiView::setGui(const GuiPtr& gui)
 
 	if (_gui != NULL)
 	{
-		GuiWindowDefPtr bgWindowDef = _gui->findWindowDef("backgroundImage");
+		IGuiWindowDefPtr bgWindowDef = _gui->findWindowDef("backgroundImage");
 		if (!bgWindowDef)
 		{
 			bgWindowDef = _gui->findWindowDef("backgroundmulti");
