@@ -3,20 +3,16 @@
 #include "itextstream.h"
 #include "parser/DefTokeniser.h"
 #include "Gui.h"
+#include "GuiExpression.h"
+#include "Variable.h"
 
-#include <boost/algorithm/string/case_conv.hpp>
-#include <boost/algorithm/string/trim.hpp>
-#include <boost/algorithm/string/predicate.hpp>
-#include <boost/lexical_cast.hpp>
+#include "string/case_conv.h"
+#include "string/trim.h"
+#include "string/predicate.h"
 
 namespace gui
 {
 
-bool Variable::assignValueFromString(const std::string& val)
-{
-	return true;
-}
-
 GuiScript::GuiScript(GuiWindowDef& owner) :
 	_owner(owner),
 	_ip(0),
@@ -29,8 +25,8 @@ void GuiScript::parseIfStatement(parser::DefTokeniser& tokeniser)
 	// The initial "if" has already been parsed
 	StatementPtr ifStatement(new Statement(Statement::ST_IF));
 
-	tokeniser.assertNextToken("(");
-	ifStatement->args.push_back(getIfExpression(tokeniser)); // condition
+	// Any opening and closing parentheses are handled by the expression parser
+	ifStatement->_condition = getIfExpression(tokeniser); // condition
 
 	// Add the statement at the current position
 	pushStatement(ifStatement);
@@ -70,10 +66,18 @@ void GuiScript::parseSetStatement(parser::DefTokeniser& tokeniser)
 	// Prototype: set [window::]<variable> <value>
 	StatementPtr st(new Statement(Statement::ST_SET));
 
-	st->args.push_back(getExpression(tokeniser)); // variable
-	st->args.push_back(getExpression(tokeniser)); // value
+	st->args.push_back(_owner.parseString(tokeniser)); // variable
 
-	tokeniser.assertNextToken(";");
+	// Add all tokens up to the semicolon as arguments
+	while (true)
+	{
+		std::string token = tokeniser.peek();
+
+		// Sometimes the semicolon is missing
+		if (token == ";" || token == "}") break;
+
+		st->args.push_back(ConstantExpression<std::string>::Create(tokeniser.nextToken())); // argument
+	}
 
 	pushStatement(st);
 }
@@ -83,21 +87,24 @@ void GuiScript::parseTransitionStatement(parser::DefTokeniser& tokeniser)
 	// Prototype: transition [window::]<variable> <from> <to> <time> [ <accel> <decel> ]
 	StatementPtr st(new Statement(Statement::ST_TRANSITION));
 
-	st->args.push_back(getExpression(tokeniser)); // variable
-	st->args.push_back(getExpression(tokeniser)); // from
-	st->args.push_back(getExpression(tokeniser)); // to
-	st->args.push_back(getExpression(tokeniser)); // time
+	st->args.push_back(ConstantExpression<std::string>::Create(tokeniser.nextToken())); // variable
 
-	std::string token = tokeniser.nextToken();
+	st->args.push_back(ConstantExpression<std::string>::Create(tokeniser.nextToken())); // from
+	st->args.push_back(ConstantExpression<std::string>::Create(tokeniser.nextToken())); // to
+	st->args.push_back(ConstantExpression<std::string>::Create(tokeniser.nextToken())); // time
 
-	if (token != ";")
+	if (tokeniser.peek() != ";")
 	{
 		// no semicolon, parse optional acceleration and deceleration
-		st->args.push_back(token);						// accel
-		st->args.push_back(getExpression(tokeniser));	// decel
+		st->args.push_back(ConstantExpression<std::string>::Create(tokeniser.nextToken())); 	// accel
+		st->args.push_back(ConstantExpression<std::string>::Create(tokeniser.nextToken()));	// decel
 
 		tokeniser.assertNextToken(";");
 	}
+	else
+	{
+		tokeniser.nextToken(); // pull semicolon
+	}
 
 	pushStatement(st);
 }
@@ -107,7 +114,7 @@ void GuiScript::parseSetFocusStatement(parser::DefTokeniser& tokeniser)
 	// Prototype: setFocus <window>
 	StatementPtr st(new Statement(Statement::ST_SET_FOCUS));
 
-	st->args.push_back(getExpression(tokeniser)); // window
+	st->args.push_back(_owner.parseString(tokeniser)); // window
 	tokeniser.assertNextToken(";");
 
 	pushStatement(st);
@@ -127,7 +134,7 @@ void GuiScript::parseResetTimeStatement(parser::DefTokeniser& tokeniser)
 	// Prototype: resetTime [<window>] [<time>]
 	StatementPtr st(new Statement(Statement::ST_RESET_TIME));
 
-	std::string token = tokeniser.nextToken();
+	std::string token = tokeniser.peek();
 
 	if (token != ";")
 	{
@@ -135,23 +142,33 @@ void GuiScript::parseResetTimeStatement(parser::DefTokeniser& tokeniser)
 		try
         {
 			// Remove quotes from string before checking numerics
-			std::string trimmed = boost::algorithm::trim_copy_if(token, boost::algorithm::is_any_of("\""));
+			std::string trimmed = string::trim_copy(token, "\"");
 
 			// Try to cast the string to a number, throws
-			boost::lexical_cast<std::size_t>(trimmed);
+			std::stoul(trimmed);
 
 			// Cast succeeded this is just the time for the current window
-			st->args.push_back(trimmed);
-
-			tokeniser.assertNextToken(";");
+			st->args.push_back(_owner.parseString(tokeniser));
         }
-		catch (boost::bad_lexical_cast&)
+		catch (std::logic_error&)
         {
             // Not a number, must be window plus time
-			st->args.push_back(token); // window
-			st->args.push_back(getExpression(tokeniser)); // time
-			tokeniser.assertNextToken(";");
+			st->args.push_back(_owner.parseString(tokeniser)); // window
+			st->args.push_back(_owner.parseString(tokeniser)); // time
         }
+
+		// Reset statement complete, check the next token, as some 
+		// GUI scripts don't bother writing an ending semicolon before the closing brace
+		std::string next = tokeniser.peek();
+
+		if (next == ";" || next == "}")
+		{
+			tokeniser.nextToken(); // exhaust
+		}
+		else
+		{
+			tokeniser.assertNextToken(";");
+		}
 	}
 
 	pushStatement(st);
@@ -162,7 +179,7 @@ void GuiScript::parseShowCursorStatement(parser::DefTokeniser& tokeniser)
 	// Prototype: showCursor <bool>
 	StatementPtr st(new Statement(Statement::ST_SHOW_CURSOR));
 
-	st->args.push_back(getExpression(tokeniser)); // boolean
+	st->args.push_back(_owner.parseString(tokeniser)); // boolean
 	tokeniser.assertNextToken(";");
 
 	pushStatement(st);
@@ -182,7 +199,7 @@ void GuiScript::parseLocalSoundStatement(parser::DefTokeniser& tokeniser)
 	// Prototype: localSound <sound>
 	StatementPtr st(new Statement(Statement::ST_LOCALSOUND));
 
-	st->args.push_back(getExpression(tokeniser)); // sound
+	st->args.push_back(_owner.parseString(tokeniser)); // sound
 	tokeniser.assertNextToken(";");
 
 	pushStatement(st);
@@ -193,7 +210,7 @@ void GuiScript::parseRunScriptStatement(parser::DefTokeniser& tokeniser)
 	// Prototype: runScript <function>
 	StatementPtr st(new Statement(Statement::ST_RUNSCRIPT));
 
-	st->args.push_back(getExpression(tokeniser)); // function
+	st->args.push_back(_owner.parseString(tokeniser)); // function
 	tokeniser.assertNextToken(";");
 
 	pushStatement(st);
@@ -223,7 +240,7 @@ void GuiScript::switchOnToken(const std::string& token, parser::DefTokeniser& to
 		while (tokeniser.hasMoreTokens() && _curLevel == blockLevel)
 		{
 			std::string nextToken = tokeniser.nextToken();
-			boost::algorithm::to_lower(nextToken);
+			string::to_lower(nextToken);
 
 			switchOnToken(nextToken, tokeniser);
 		}
@@ -291,7 +308,7 @@ void GuiScript::parseStatement(parser::DefTokeniser& tokeniser)
 	}
 
 	std::string token = tokeniser.nextToken();
-	boost::algorithm::to_lower(token);
+	string::to_lower(token);
 
 	switchOnToken(token, tokeniser);
 }
@@ -318,38 +335,14 @@ std::size_t GuiScript::pushStatement(const StatementPtr& statement)
 	return _statements.size() - 1;
 }
 
-std::string GuiScript::getExpression(parser::DefTokeniser& tokeniser)
+GuiExpressionPtr GuiScript::getExpression(parser::DefTokeniser& tokeniser)
 {
-	return tokeniser.nextToken();
+	return GuiExpression::CreateFromTokens(_owner.getGui(), tokeniser);
 }
 
-std::string GuiScript::getIfExpression(parser::DefTokeniser& tokeniser)
+GuiExpressionPtr GuiScript::getIfExpression(parser::DefTokeniser& tokeniser)
 {
-	std::string rv;
-
-	std::size_t level = 1;
-
-	while (tokeniser.hasMoreTokens() && level > 0)
-	{
-		std::string token = tokeniser.nextToken();
-
-		if (token == ")")
-		{
-			level--;
-		}
-		else if (token == "(")
-		{
-			level++;
-		}
-
-		if (level > 0)
-		{
-			rv += (rv.empty()) ? "" : " ";
-			rv += token;
-		}
-	}
-
-	return rv;
+	return getExpression(tokeniser);
 }
 
 const Statement& GuiScript::getStatement(std::size_t index)
@@ -358,16 +351,9 @@ const Statement& GuiScript::getStatement(std::size_t index)
 	return *_statements[index];
 }
 
-VariablePtr GuiScript::getVariableFromExpression(const std::string& expr)
+VariablePtr GuiScript::getVariableFromExpression(const std::shared_ptr<IGuiExpression<std::string>>& expression)
 {
-	if (boost::algorithm::starts_with(expr, "gui::"))
-	{
-		// Is a GUI state variable
-		return VariablePtr(new GuiStateVariable(
-			_owner.getGui(),
-			expr.substr(5)
-		));
-	}
+	std::string expr = expression->evaluate();
 
 	// Not a gui:: variable, check if a namespace has been specified
 	std::size_t ddPos = expr.find("::");
@@ -377,13 +363,19 @@ VariablePtr GuiScript::getVariableFromExpression(const std::string& expr)
 		// Retrieve the windowDef name
 		std::string windowDefName = expr.substr(0, ddPos);
 
-		// Look up the windowDef
-		GuiWindowDefPtr windowDef = _owner.getGui().findWindowDef(windowDefName);
+		if (windowDefName == "gui")
+		{
+			// Is a GUI state variable
+			return std::make_shared<GuiStateVariable>(_owner.getGui(), expr.substr(ddPos + 2));
+		}
 
-		if (windowDef != NULL)
+		// Look up the windowDef
+		IGuiWindowDefPtr windowDef = _owner.getGui().findWindowDef(windowDefName);
+
+		if (windowDef)
 		{
 			// Cut off the "<windowDef>::" from the name
-			return VariablePtr(new WindowDefVariable(*windowDef, expr.substr(ddPos+2)));
+			return std::make_shared<AssignableWindowVariable>(*windowDef, expr.substr(ddPos+2));
 		}
 		else
 		{
@@ -394,19 +386,21 @@ VariablePtr GuiScript::getVariableFromExpression(const std::string& expr)
 	else
 	{
 		// Use the owner windowDef if no namespace was defined
-		return VariablePtr(new WindowDefVariable(_owner, expr));
+		return std::make_shared<AssignableWindowVariable>(_owner, expr);
 	}
 }
 
-std::string GuiScript::getValueFromExpression(const std::string& expr)
+std::string GuiScript::getValueFromExpression(const std::shared_ptr<IGuiExpression<std::string>>& expr)
 {
-	if (boost::algorithm::starts_with(expr, "$gui::"))
+	std::string value = expr->evaluate();
+
+	if (string::starts_with(value, "$gui::"))
 	{
 		// This is the value of a GUI state variable
-		return _owner.getGui().getStateString(expr.substr(6));
+		return _owner.getGui().getStateString(value.substr(6));
 	}
 
-	return expr;
+	return value;
 }
 
 void GuiScript::execute()
@@ -431,12 +425,17 @@ void GuiScript::execute()
 				// Try to find the target variable
 				VariablePtr var = getVariableFromExpression(st.args[0]);
 
+				if (!var)
+				{
+					rWarning() << "Cannot assign to variable " << st.args[0] << std::endl;
+					continue;
+				}
+
 				std::string value = getValueFromExpression(st.args[1]);
 
-				if (var == NULL || !var->assignValueFromString(value))
+				if (!var->assignValueFromString(value))
 				{
-					rWarning() << "Cannot assign value " <<
-						st.args[1] << " to variable " << st.args[1] << std::endl;
+					rWarning() << "Cannot assign value " << st.args[1] << " to variable " << st.args[1] << std::endl;
 				}
 			}
 			break;
