@@ -7,8 +7,7 @@
 #include <vector>
 #include <list>
 #include "gamelib.h"
-#include <boost/algorithm/string/split.hpp>
-#include <boost/algorithm/string/classification.hpp>
+#include "string/split.h"
 
 #include "TextParts.h"
 #include "GuiWindowDef.h"
@@ -23,28 +22,49 @@ namespace gui
 		const std::string GKEY_MEDIUMFONT_LIMIT("/defaults/guiMediumFontLimit");
 	}
 
-RenderableText::RenderableText(const GuiWindowDef& owner) :
+RenderableText::RenderableText(const IGuiWindowDef& owner) :
 	_owner(owner)
 {}
 
 void RenderableText::printMissingGlyphSetError() const
 {
-    rConsoleError() << "[dm.gui] Font '" << _font->getName() << "'"
+    rWarning() << "[dm.gui] Font '" << _font->getName() << "'"
               << " does not have glyph set for resolution "
               << _resolution << std::endl;
 }
 
 void RenderableText::realiseFontShaders()
 {
-    fonts::IGlyphSetPtr glyphSet = _font->getGlyphSet(_resolution);
-    if (glyphSet)
-    {
-        glyphSet->realiseShaders();
-    }
-    else
-    {
-        printMissingGlyphSetError();
-    }
+	while (_resolution < fonts::Resolution::NumResolutions)
+	{
+		fonts::IGlyphSetPtr glyphSet = _font->getGlyphSet(_resolution);
+
+		if (glyphSet)
+		{
+			glyphSet->realiseShaders();
+			break;
+		}
+		else
+		{
+			switch (_resolution)
+			{
+				case fonts::Resolution12: 
+					rWarning() << "Falling back to higher resolution 24..." << std::endl;
+					_resolution = fonts::Resolution24; 
+					break;
+				case fonts::Resolution24: 
+					rWarning() << "Falling back to higher resolution 48..." << std::endl;
+					_resolution = fonts::Resolution48; 
+					break;
+				case fonts::Resolution48: 
+					rWarning() << "No resolutions to fall back." << std::endl;
+					printMissingGlyphSetError();
+					return;
+				default:
+					break;
+			}
+		}
+	}
 }
 
 void RenderableText::render()
@@ -68,14 +88,14 @@ void RenderableText::recompile()
 
 	if (_font == NULL) return; // Rendering not possible
 
-	std::string text = _owner.getText();
+	std::string text = _owner.text;
 
 	typedef std::vector<TextLinePtr> TextLines;
 	TextLines lines;
 
 	// Split the text into paragraphs
 	std::vector<std::string> paragraphs;
-	boost::algorithm::split(paragraphs, text, boost::algorithm::is_any_of("\n"));
+	string::split(paragraphs, text, "\n", false);
 
     fonts::IGlyphSetPtr gsp = _font->getGlyphSet(_resolution);
     if (!gsp)
@@ -98,31 +118,30 @@ void RenderableText::recompile()
 	// The distance from the top of the rectangle to the baseline
 	double startingBaseLine = lrint(_owner.textscale * maxGlyphHeight + 2) + _owner.textaligny;
 
+	Vector4 ownerRec = _owner.rect.getValue();
+
 	for (std::size_t p = 0; p < paragraphs.size(); ++p)
 	{
 		// Check if more lines are possible, if at least one line is in the rectangle
 		if (!lines.empty())
 		{
 			double curYPos = lineHeight * lines.size() + startingBaseLine;
-			if (curYPos > _owner.rect[3] - 2) break;
+			if (curYPos > ownerRec[3] - 2) break;
 		}
 
 		// Split the paragraphs into words
 		std::list<std::string> words;
-		boost::algorithm::split(words, paragraphs[p], boost::algorithm::is_any_of(" \t"));
+		string::split(words, paragraphs[p], " \t", false);
 
 		// Add the words to lines
-		TextLinePtr curLine(new TextLine(_owner.rect[2] - 2 - _owner.textalignx, scale));
+		TextLinePtr curLine(new TextLine(ownerRec[2] - 2 - _owner.textalignx, scale));
+
+		const std::string space(" ");
 
 		while (!words.empty())
 		{
-			// Empty words are stemming from an extra space character, re-add that
-			if (words.front().empty())
-			{
-				curLine->addChar(' ', glyphSet, true);
-				words.pop_front();
-				continue;
-			}
+			// Empty words are stemming from an extra space character, treat them as space
+			const std::string& wordToAdd = words.front().empty() ? space : words.front();
 
 			// If nowrap set to true, force words into this line
 			bool added = curLine->addWord(words.front(), glyphSet, _owner.nowrap);
@@ -188,12 +207,12 @@ void RenderableText::recompile()
 
 			// Check if more lines are possible
 			double curYPos = lineHeight * lines.size() + startingBaseLine;
-			if (curYPos > _owner.rect[3] - 2) break;
+			if (curYPos > ownerRec[3] - 2) break;
 
 			// Allocate a new line, but only if we have any more words in this paragraph
 			if (!words.empty())
 			{
-				curLine = TextLinePtr(new TextLine(_owner.rect[2] - 2 - _owner.textalignx, scale));
+				curLine = TextLinePtr(new TextLine(ownerRec[2] - 2 - _owner.textalignx, scale));
 			}
 		}
 
@@ -218,7 +237,7 @@ void RenderableText::recompile()
 	for (TextLines::const_iterator line = lines.begin(); line != lines.end(); ++line)
 	{
 		// Move the lines into our GUI rectangle
-		(*line)->offset(Vector2(_owner.rect[0], _owner.rect[1]));
+		(*line)->offset(Vector2(ownerRec[0], ownerRec[1]));
 
 		for (TextLine::Chars::const_iterator c = (*line)->getChars().begin();
 			 c != (*line)->getChars().end(); ++c)
@@ -259,10 +278,10 @@ double RenderableText::getAlignmentCorrection(double lineWidth)
 		break;
 	case 1: // center
 		// Somehow D3 adds a 1 pixel offset to the left
-		xoffset = 1 + (_owner.rect[2] - lineWidth) / 2;
+		xoffset = 1 + (_owner.rect.getValue()[2] - lineWidth) / 2;
 		break;
 	case 2: // right
-		xoffset = _owner.rect[2] - 2 - lineWidth;
+		xoffset = _owner.rect.getValue()[2] - 2 - lineWidth;
 		break;
 	};
 
@@ -271,15 +290,19 @@ double RenderableText::getAlignmentCorrection(double lineWidth)
 
 void RenderableText::ensureFont()
 {
-	if (_owner.font.empty()) return; // no font specified
+	if (_owner.font.getValue().empty()) return; // no font specified
 
 	if (_font != NULL) return; // already realised
 
-	_font = GlobalFontManager().findFontInfo(_owner.font);
+	// Cut off the "fonts/" part
+	std::string font = _owner.font;
+	string::replace_first(font, "fonts/", "");
+
+	_font = GlobalFontManager().findFontInfo(font);
 
 	if (_font == NULL)
 	{
-		rWarning() << "Cannot find font " << _owner.font
+		rWarning() << "Cannot find font " << _owner.font.getValue()
 			<< " in windowDef " << _owner.name << std::endl;
 		return;
 	}
