@@ -5,9 +5,8 @@
 #include "os/path.h"
 #include "string/convert.h"
 
-#include <boost/algorithm/string/case_conv.hpp>
-#include <boost/algorithm/string/predicate.hpp>
-#include <boost/algorithm/string/erase.hpp>
+#include "string/predicate.h"
+#include <fmt/format.h>
 #include <functional>
 
 namespace eclass
@@ -27,20 +26,18 @@ const std::string ATTACH_POS_JOINT = "attach_pos_joint";
 const std::string ATTACH_POS_ANGLES = "attach_pos_angles";
 
 // Extract and return the string suffix for a key (which might be the empty
-// string if there is no suffix). Returns boost::none if the key did not match
+// string if there is no suffix). Returns false if the key did not match
 // the prefix.
-boost::optional<std::string> suffixedKey(const std::string& key,
-                                         const std::string& prefix)
+bool tryGetSuffixedKey(const std::string& key, const std::string& prefix, std::string& suffixedOutput)
 {
-    if (boost::algorithm::istarts_with(key, prefix))
+    if (string::istarts_with(key, prefix))
     {
-        std::string suffixStr = boost::algorithm::erase_first_copy(key, prefix);
-        return suffixStr;
-    }
-    else
-    {
-        return boost::none;
+		suffixedOutput = key.substr(prefix.length());
+		return true;
     }
+    
+	suffixedOutput.clear();
+	return false;
 }
 
 } // namespace
@@ -134,35 +131,35 @@ public:
     // Attempt to extract attachment data from the given key/value pair
     void parseDefAttachKeys(const std::string& key, const std::string& value)
     {
-        boost::optional<std::string> keySuffix;
+        std::string suffix;
 
-        if ((keySuffix = suffixedKey(key, DEF_ATTACH)))
+        if (tryGetSuffixedKey(key, DEF_ATTACH, suffix))
         {
-            _objects[*keySuffix].className = value;
+            _objects[suffix].className = value;
         }
-        else if ((keySuffix = suffixedKey(key, NAME_ATTACH)))
+        else if (tryGetSuffixedKey(key, NAME_ATTACH, suffix))
         {
-            _objects[*keySuffix].name = value;
+            _objects[suffix].name = value;
         }
-        else if ((keySuffix = suffixedKey(key, POS_ATTACH)))
+        else if (tryGetSuffixedKey(key, POS_ATTACH, suffix))
         {
-            _objects[*keySuffix].posName = value;
+            _objects[suffix].posName = value;
         }
-        else if ((keySuffix = suffixedKey(key, ATTACH_POS_NAME)))
+        else if (tryGetSuffixedKey(key, ATTACH_POS_NAME, suffix))
         {
-            _positions[*keySuffix].name = value;
+            _positions[suffix].name = value;
         }
-        else if ((keySuffix = suffixedKey(key, ATTACH_POS_ORIGIN)))
+        else if (tryGetSuffixedKey(key, ATTACH_POS_ORIGIN, suffix))
         {
-            _positions[*keySuffix].origin = string::convert<Vector3>(value);
+            _positions[suffix].origin = string::convert<Vector3>(value);
         }
-        else if ((keySuffix = suffixedKey(key, ATTACH_POS_ANGLES)))
+        else if (tryGetSuffixedKey(key, ATTACH_POS_ANGLES, suffix))
         {
-            _positions[*keySuffix].angles = string::convert<Vector3>(value);
+            _positions[suffix].angles = string::convert<Vector3>(value);
         }
-        else if ((keySuffix = suffixedKey(key, ATTACH_POS_JOINT)))
+        else if (tryGetSuffixedKey(key, ATTACH_POS_JOINT, suffix))
         {
-            _positions[*keySuffix].joint = value;
+            _positions[suffix].joint = value;
         }
     }
 
@@ -295,10 +292,10 @@ void Doom3EntityClass::setColour(const Vector3& colour)
 
     // Define fill and wire versions of the entity colour
     _fillShader = _colourTransparent ?
-        (boost::format("[%f %f %f]") % _colour[0] % _colour[1] % _colour[2]).str() :
-        (boost::format("(%f %f %f)") % _colour[0] % _colour[1] % _colour[2]).str();
+        fmt::format("[{0:f} {1:f} {2:f}]", _colour[0], _colour[1], _colour[2]) :
+        fmt::format("({0:f} {1:f} {2:f})", _colour[0], _colour[1], _colour[2]);
 
-    _wireShader = (boost::format("<%f %f %f>") % _colour[0] % _colour[1] % _colour[2]).str();
+    _wireShader = fmt::format("<{0:f} {1:f} {2:f}>", _colour[0], _colour[1], _colour[2]);
 }
 
 const Vector3& Doom3EntityClass::getColour() const {
@@ -376,7 +373,7 @@ void Doom3EntityClass::forEachClassAttribute(
          ++i)
     {
         // Visit if it is a non-editor key or we are visiting all keys
-        if (editorKeys || !boost::algorithm::istarts_with(*i->first, "editor_"))
+        if (editorKeys || !string::istarts_with(*i->first, "editor_"))
         {
             visitor(i->second);
         }
@@ -585,7 +582,7 @@ void Doom3EntityClass::parseFromTokens(parser::DefTokeniser& tokeniser)
         {
             setIsLight(value == "idLight");
         }
-        else if (boost::algorithm::istarts_with(key, "editor_"))
+        else if (string::istarts_with(key, "editor_"))
         {
             parseEditorSpawnarg(key, value);
         }
