@@ -13,7 +13,7 @@
 #include "entitylib.h"
 #include "gamelib.h"
 
-#include <boost/algorithm/string/replace.hpp>
+#include "string/replace.h"
 #include <iostream>
 
 #include "i18n.h"
@@ -92,8 +92,7 @@ IEntityNodePtr Doom3EntityCreator::createEntity(const IEntityClassPtr& eclass)
 		 * so that nothing bad can happen (for example, the colon character
 		 * seems to be causing problems in Doom 3 Scripting)
 		 */
-		std::string entityName =
-			boost::algorithm::replace_all_copy(eclassName, ":", "_") + "_1";
+		std::string entityName = string::replace_all_copy(eclassName, ":", "_") + "_1";
 
 		node->getEntity().setKeyValue("name", entityName);
 	}
@@ -129,13 +128,13 @@ void Doom3EntityCreator::connectEntities(const scene::INodePtr& source,
 	for (int i = 0; i < 1024; ++i) {
 
 		// Construct candidate key by appending number to "target"
-		std::string targetKey = (boost::format("target%i") % i).str();
+		std::string targetKey = fmt::format("target{0:d}", i);
 
 		// If the source entity does not have this key, add it and finish,
 		// otherwise continue looping
-		if (e1->getKeyValue(targetKey).empty()) {
-			e1->setKeyValue(targetKey,
-			                e2->getKeyValue("name"));
+		if (e1->getKeyValue(targetKey).empty())
+		{
+			e1->setKeyValue(targetKey, e2->getKeyValue("name"));
 			break;
 		}
 	}
