@@ -49,9 +49,10 @@ EntityNode::~EntityNode()
 
 void EntityNode::construct()
 {
-    _eclass->changedSignal().connect(
-        sigc::mem_fun(_keyObservers, &KeyObserverMap::refreshObservers)
-    );
+	_eclassChangedConn = _eclass->changedSignal().connect([this]()
+	{
+		this->onEntityClassChanged();
+	});
 
 	TargetableNode::construct();
 
@@ -80,9 +81,17 @@ void EntityNode::destruct()
 	removeKeyObserver("_color", _colourKey);
 	removeKeyObserver("name", _nameKey);
 
+	_eclassChangedConn.disconnect();
+
 	TargetableNode::destruct();
 }
 
+void EntityNode::onEntityClassChanged()
+{
+	// By default, we notify the KeyObservers attached to this entity
+	_keyObservers.refreshObservers();
+}
+
 void EntityNode::addKeyObserver(const std::string& key, KeyObserver& observer)
 {
 	_keyObservers.insert(key, observer);
@@ -163,6 +172,7 @@ void EntityNode::onInsertIntoScene(scene::IMapRootNode& root)
     GlobalCounters().getCounter(counterEntities).increment();
 
 	_entity.connectUndoSystem(root.getUndoChangeTracker());
+	_modelKey.connectUndoSystem(root.getUndoChangeTracker());
 
 	SelectableNode::onInsertIntoScene(root);
     TargetableNode::onInsertIntoScene(root);
@@ -173,6 +183,7 @@ void EntityNode::onRemoveFromScene(scene::IMapRootNode& root)
     TargetableNode::onRemoveFromScene(root);
 	SelectableNode::onRemoveFromScene(root);
 
+	_modelKey.disconnectUndoSystem(root.getUndoChangeTracker());
 	_entity.disconnectUndoSystem(root.getUndoChangeTracker());
 
     GlobalCounters().getCounter(counterEntities).decrement();
