@@ -57,10 +57,6 @@ void LightNode::construct()
 	_light.construct();
 }
 
-const Matrix4& LightNode::getLocalPivot() const {
-	return _light.getLocalPivot();
-}
-
 // Snappable implementation
 void LightNode::snapto(float snap) {
 	_light.snapto(snap);
@@ -91,18 +87,18 @@ float LightNode::getShaderParm(int parmNum) const
 	return EntityNode::getShaderParm(parmNum);
 }
 
-void LightNode::onInsertIntoScene()
+void LightNode::onInsertIntoScene(scene::IMapRootNode& root)
 {
 	// Call the base class first
-	EntityNode::onInsertIntoScene();
+	EntityNode::onInsertIntoScene(root);
 
 	GlobalRenderSystem().attachLight(*this);
 }
 
-void LightNode::onRemoveFromScene()
+void LightNode::onRemoveFromScene(scene::IMapRootNode& root)
 {
 	// Call the base class first
-	EntityNode::onRemoveFromScene();
+	EntityNode::onRemoveFromScene(root);
 
 	GlobalRenderSystem().detachLight(*this);
 
@@ -142,6 +138,19 @@ void LightNode::setSelectedComponents(bool select, SelectionSystem::EComponentMo
 	}
 }
 
+void LightNode::invertSelectedComponents(SelectionSystem::EComponentMode mode)
+{
+	if (mode == SelectionSystem::eVertex)
+	{
+		_lightCenterInstance.invertSelected();
+		_lightTargetInstance.invertSelected();
+		_lightRightInstance.invertSelected();
+		_lightUpInstance.invertSelected();
+		_lightStartInstance.invertSelected();
+		_lightEndInstance.invertSelected();
+	}
+}
+
 void LightNode::testSelectComponents(Selector& selector, SelectionTest& test, SelectionSystem::EComponentMode mode)
 {
 	if (mode == SelectionSystem::eVertex)
@@ -251,7 +260,7 @@ scene::INodePtr LightNode::clone() const
 	return node;
 }
 
-void LightNode::selectedChangedComponent(const Selectable& selectable) {
+void LightNode::selectedChangedComponent(const ISelectable& selectable) {
 	// add the selectable to the list of selected components (see RadiantSelectionSystem::onComponentSelection)
 	GlobalSelectionSystem().onComponentSelection(Node::getSelf(), selectable);
 }
@@ -510,4 +519,9 @@ void LightNode::_applyTransformation()
 	_light.freezeTransform();
 }
 
+const Vector3& LightNode::getUntransformedOrigin()
+{
+    return _light.getUntransformedOrigin();
+}
+
 } // namespace entity
