@@ -2,8 +2,8 @@
 
 #include "GlyphInfo.h"
 #include "os/file.h"
-#include <boost/algorithm/string/case_conv.hpp>
-#include <boost/algorithm/string/replace.hpp>
+#include "string/case_conv.h"
+#include "string/replace.h"
 
 namespace fonts
 {
@@ -23,10 +23,10 @@ GlyphInfo::GlyphInfo(const q3font::Q3GlyphInfo& q3glyph)
 	t2 = q3glyph.t2;
 
 	texture = q3glyph.shaderName;
-	boost::algorithm::to_lower(texture);
+	string::to_lower(texture);
 
 	// Cut off fonts/
-	boost::algorithm::replace_first(texture, "fonts/", "");
+	string::replace_first(texture, "fonts/", "");
 
 	// Cut off file extension
 	texture = texture.substr(0, texture.rfind('.'));
