@@ -7,8 +7,7 @@
 #include "string/string.h"
 
 #include "i18n.h"
-#include <boost/format.hpp>
-#include <boost/lexical_cast.hpp>
+#include <fmt/format.h>
 
 #include "primitiveparsers/BrushDef.h"
 #include "primitiveparsers/BrushDef3.h"
@@ -42,7 +41,7 @@ void Quake3MapReader::readFromStream(std::istream& stream)
 		}
 		catch (FailureException& e)
 		{
-			std::string text = (boost::format(_("Failed parsing entity %d:\n%s")) % _entityCount % e.what()).str();
+			std::string text = fmt::format(_("Failed parsing entity {0:d}:\n{1}"), _entityCount, e.what());
 
 			// Re-throw with more text
 			throw FailureException(text);
@@ -99,7 +98,7 @@ void Quake3MapReader::parsePrimitive(parser::DefTokeniser& tok, const scene::INo
 
 		if (!primitive)
 		{
-			std::string text = (boost::format(_("Primitive #%d: parse error")) % _primitiveCount).str();
+			std::string text = fmt::format(_("Primitive #{0:d}: parse error"), _primitiveCount);
 			throw FailureException(text);
 		}
 
@@ -109,7 +108,7 @@ void Quake3MapReader::parsePrimitive(parser::DefTokeniser& tok, const scene::INo
 	catch (parser::ParseException& e)
 	{
 		// Translate ParseExceptions to FailureExceptions
-		std::string text = (boost::format(_("Primitive #%d: parse exception %s")) % _primitiveCount % e.what()).str();
+		std::string text = fmt::format(_("Primitive #{0:d}: parse exception {1}"), _primitiveCount, e.what());
 		throw FailureException(text);
 	}
 }
@@ -200,7 +199,7 @@ void Quake3MapReader::parseEntity(parser::DefTokeniser& tok)
 	        // Sanity check (invalid number of tokens will get us out of sync)
 	        if (value == "{" || value == "}")
 			{
-				std::string text = (boost::format(_("Parsed invalid value '%s' for key '%s'")) % value % token).str();
+				std::string text = fmt::format(_("Parsed invalid value '{0}' for key '{1}'"), value, token);
 	            throw FailureException(text);
 	        }
 
