@@ -3,7 +3,7 @@
 #include "shaderlib.h"
 #include "ipatch.h"
 
-#include <boost/algorithm/string/predicate.hpp>
+#include "string/predicate.h"
 
 namespace map
 {
@@ -152,7 +152,7 @@ private:
 		}
 		else
 		{
-			if (boost::algorithm::starts_with(shaderName, GlobalTexturePrefix_get()))
+			if (string::starts_with(shaderName, GlobalTexturePrefix_get()))
 			{
 				// Q3-style patchDef2 has the "textures/" not written to the map, cut it off
 				stream << "" << shader_get_textureName(shaderName.c_str()) << " ";
