@@ -1,10 +1,12 @@
 #pragma once
 
+#include "Transformable.h"
 #include "iselectiontest.h"
 #include "irender.h"
 #include "itraceable.h"
 #include "modelskin.h"
 #include "irenderable.h"
+#include "pivot.h"
 #include "render/VectorLightList.h"
 #include "RenderablePicoModel.h"
 #include "scene/Node.h"
@@ -17,7 +19,8 @@ class PicoModelNode :
 	public SelectionTestable,
 	public LitObject,
 	public SkinnedModel,
-	public ITraceable
+	public ITraceable,
+    public Transformable
 {
 private:
 	// The actual model
@@ -42,18 +45,22 @@ public:
 
 	virtual ~PicoModelNode();
 
+	virtual void onInsertIntoScene(scene::IMapRootNode& root) override;
+	virtual void onRemoveFromScene(scene::IMapRootNode& root) override;
+
 	// ModelNode implementation
-	virtual const IModel& getIModel() const;
-	virtual IModel& getIModel();
+	const IModel& getIModel() const override;
+	IModel& getIModel() override;
+	bool hasModifiedScale() override;
 
 	// SkinnedModel implementation
 	// Skin changed notify
-	void skinChanged(const std::string& newSkinName);
+	void skinChanged(const std::string& newSkinName) override;
 	// Returns the name of the currently active skin
-	std::string getSkin() const;
+	std::string getSkin() const override;
 
 	// Bounded implementation
-	virtual const AABB& localAABB() const;
+	virtual const AABB& localAABB() const override;
 
 	// Lights changed function
 	void lightsChanged()
@@ -62,20 +69,20 @@ public:
 	}
 
 	// SelectionTestable implementation
-	void testSelect(Selector& selector, SelectionTest& test);
+	void testSelect(Selector& selector, SelectionTest& test) override;
 
-	virtual std::string name() const;
-	Type getNodeType() const;
+	virtual std::string name() const override;
+	Type getNodeType() const override;
 
 	const RenderablePicoModelPtr& getModel() const;
 	void setModel(const RenderablePicoModelPtr& model);
 
 	// LitObject test function
-	bool intersectsLight(const RendererLight& light) const;
+	bool intersectsLight(const RendererLight& light) const override;
 	// Add a light to this model instance
-	void insertLight(const RendererLight& light);
+	void insertLight(const RendererLight& light) override;
 	// Clear all lights from this model instance
-	void clearLights();
+	void clearLights() override;
 
 	// Renderable implementation
   	void renderSolid(RenderableCollector& collector, const VolumeTest& volume) const override;
@@ -88,7 +95,11 @@ public:
 	}
 
 	// Traceable implementation
-	bool getIntersection(const Ray& ray, Vector3& intersection);
+	bool getIntersection(const Ray& ray, Vector3& intersection) override;
+
+protected:
+	virtual void _onTransformationChanged() override;
+	virtual void _applyTransformation() override;
 
 private:
 	// Instance render function
