@@ -1,5 +1,18 @@
 #include "ScriptingSystem.h"
 
+#include <pybind11/pybind11.h>
+#include <pybind11/attr.h>
+#include <pybind11/stl_bind.h>
+#include <pybind11/eval.h>
+
+#if (PYBIND11_VERSION_MAJOR > 2) || (PYBIND11_VERSION_MAJOR == 2 && PYBIND11_VERSION_MINOR >= 2)
+#define DR_PYBIND_HAS_EMBED_H
+#endif
+
+#ifdef DR_PYBIND_HAS_EMBED_H
+#include <pybind11/embed.h>
+#endif
+
 #include "i18n.h"
 #include "itextstream.h"
 #include "iradiant.h"
@@ -28,6 +41,9 @@
 #include "interfaces/SoundInterface.h"
 #include "interfaces/DialogInterface.h"
 #include "interfaces/SelectionSetInterface.h"
+#include "interfaces/SelectionGroupInterface.h"
+
+#include "PythonModule.h"
 
 #include "ScriptWindow.h"
 #include "SceneNodeBuffer.h"
@@ -37,10 +53,11 @@
 #include "os/fs.h"
 #include "os/file.h"
 #include "os/path.h"
-#include <boost/algorithm/string/case_conv.hpp>
-#include <boost/python/suite/indexing/vector_indexing_suite.hpp>
+#include <functional>
+#include "string/case_conv.h"
 
-namespace script {
+namespace script 
+{
 
 ScriptingSystem::ScriptingSystem() :
 	_outputWriter(false, _outputBuffer),
@@ -59,16 +76,20 @@ void ScriptingSystem::addInterface(const std::string& name, const IScriptInterfa
 	// Try to insert
 	_interfaces.push_back(NamedInterface(name, iface));
 
-	if (_initialised) {
+	if (_initialised) 
+	{
 		// Add the interface at once, all the others are already added
-		iface->registerInterface(_mainObjects->mainNamespace);
+		iface->registerInterface(PythonModule::GetModule(), PythonModule::GetGlobals());
 	}
 }
 
-bool ScriptingSystem::interfaceExists(const std::string& name) {
+bool ScriptingSystem::interfaceExists(const std::string& name)
+{
 	// Traverse the interface list
-	for (Interfaces::iterator i = _interfaces.begin(); i != _interfaces.end(); ++i) {
-		if (i->first == name) {
+	for (const NamedInterface& i : _interfaces)
+	{
+		if (i.first == name)
+		{
 			return true;
 		}
 	}
@@ -76,7 +97,13 @@ bool ScriptingSystem::interfaceExists(const std::string& name) {
 	return false;
 }
 
-void ScriptingSystem::executeScriptFile(const std::string& filename) {
+void ScriptingSystem::executeScriptFile(const std::string& filename)
+{
+	executeScriptFile(filename, false);
+}
+
+void ScriptingSystem::executeScriptFile(const std::string& filename, bool setExecuteCommandAttr)
+{
 	try
 	{
         std::string filePath = _scriptPath + filename;
@@ -89,33 +116,30 @@ void ScriptingSystem::executeScriptFile(const std::string& filename) {
             return;
         }
 
+		py::dict locals;
+
+		if (setExecuteCommandAttr)
+		{
+			locals["__executeCommand__"] = true;
+		}
+
 		// Attempt to run the specified script
-		boost::python::object ignored = boost::python::exec_file(
-            filePath.c_str(),
-			_mainObjects->mainNamespace,
-			_mainObjects->globals
-		);
+		py::eval_file(filePath, PythonModule::GetGlobals(), locals);
 	}
-    catch (std::invalid_argument& e) // thrown when the file doesn't exist
+    catch (std::invalid_argument& e)
     {
         rError() << "Error trying to execute file " << filename << ": " << e.what() << std::endl;
     }
-	catch (const boost::python::error_already_set&) {
-		rError() << "Error while executing file: "
-					<< filename << ": " << std::endl;
-
-		// Dump the error to the console, this will invoke the PythonConsoleWriter
-		PyErr_Print();
-		PyErr_Clear();
-
-		// Python is usually not appending line feeds...
-		rMessage() << std::endl;
+	catch (const py::error_already_set& ex)
+	{
+		rError() << "Error while executing file: " << filename << ": " << std::endl;
+		rError() << ex.what() << std::endl;
 	}
 }
 
 ExecutionResultPtr ScriptingSystem::executeString(const std::string& scriptString)
 {
-	ExecutionResultPtr result(new ExecutionResult);
+	ExecutionResultPtr result = std::make_shared<ExecutionResult>();
 
 	result->errorOccurred = false;
 
@@ -125,20 +149,19 @@ ExecutionResultPtr ScriptingSystem::executeString(const std::string& scriptStrin
 
 	try
 	{
+		std::string fullScript = "import " + std::string(PythonModule::NAME()) + " as DR\n"
+			"from " + std::string(PythonModule::NAME()) + " import *\n";
+		fullScript.append(scriptString);
+
 		// Attempt to run the specified script
-		boost::python::object ignored = boost::python::exec(
-			scriptString.c_str(),
-			_mainObjects->mainNamespace,
-			_mainObjects->globals
-		);
+		py::eval<py::eval_statements>(fullScript, PythonModule::GetGlobals());
 	}
-	catch (const boost::python::error_already_set&)
+	catch (py::error_already_set& ex)
 	{
+		_errorBuffer.append(ex.what());
 		result->errorOccurred = true;
 
-		// Dump the error to the console, this will invoke the PythonConsoleWriter
-		PyErr_Print();
-		PyErr_Clear();
+		rError() << "Error executing script: " << ex.what() << std::endl;
 	}
 
 	result->output += _outputBuffer + "\n";
@@ -150,35 +173,55 @@ ExecutionResultPtr ScriptingSystem::executeString(const std::string& scriptStrin
 	return result;
 }
 
-void ScriptingSystem::initialise()
+void ScriptingSystem::addInterfacesToModule(py::module& mod, py::dict& globals)
 {
 	// Add the registered interfaces
-	try {
-		for (Interfaces::iterator i = _interfaces.begin(); i != _interfaces.end(); ++i) {
-			// Handle each interface in its own try/catch block
-			try
-			{
-				i->second->registerInterface(_mainObjects->mainNamespace);
-			}
-			catch (const boost::python::error_already_set&)
-			{
-				rError() << "Error while initialising interface "
-					<< i->first << ": " << std::endl;
-
-				PyErr_Print();
-				PyErr_Clear();
-
-				rMessage() << std::endl;
-			}
+	for (NamedInterface& i : _interfaces)
+	{
+		// Handle each interface in its own try/catch block
+		try
+		{
+			i.second->registerInterface(mod, globals);
+		}
+		catch (const py::error_already_set& ex)
+		{
+			rError() << "Error while initialising interface " << i.first << ": " << std::endl;
+			rError() << ex.what() << std::endl;
 		}
 	}
-	catch (const boost::python::error_already_set&) {
-		// Dump the error to the console, this will invoke the PythonConsoleWriter
-		PyErr_Print();
-		PyErr_Clear();
+}
 
-		// Python is usually not appending line feeds...
-		rMessage() << std::endl;
+void ScriptingSystem::initialise()
+{
+	// The finalize_interpreter() function is not available in older versions
+#ifdef DR_PYBIND_HAS_EMBED_H
+	py::initialize_interpreter();
+#else
+	Py_Initialize();
+#endif
+
+	{
+		try
+		{
+			// Import the darkradiant module
+			py::module::import(PythonModule::NAME());
+
+			// Construct the console writer interface
+			PythonConsoleWriterClass consoleWriter(PythonModule::GetModule(), "PythonConsoleWriter");
+			consoleWriter.def(py::init<bool, std::string&>());
+			consoleWriter.def("write", &PythonConsoleWriter::write);
+
+			// Redirect stdio output to our local ConsoleWriter instances
+			py::module::import("sys").attr("stderr") = &_errorWriter;
+			py::module::import("sys").attr("stdout") = &_outputWriter;
+
+			// String vector is used in multiple places
+			py::bind_vector< std::vector<std::string> >(PythonModule::GetModule(), "StringVector");
+		}
+		catch (const py::error_already_set& ex)
+		{
+			rError() << ex.what() << std::endl;
+		}
 	}
 
 	_initialised = true;
@@ -186,6 +229,9 @@ void ScriptingSystem::initialise()
 	// Start the init script
 	executeScriptFile("init.py");
 
+	// Search script folder for commands
+	reloadScripts();
+
 	// Add the scripting widget to the groupdialog
 	IGroupDialog::PagePtr page(new IGroupDialog::Page);
 
@@ -199,27 +245,32 @@ void ScriptingSystem::initialise()
 	GlobalGroupDialog().addPage(page);
 }
 
-void ScriptingSystem::runScriptFile(const cmd::ArgumentList& args) {
+void ScriptingSystem::runScriptFile(const cmd::ArgumentList& args)
+{
 	// Start the test script
 	if (args.empty()) return;
 
 	executeScriptFile(args[0].getString());
 }
 
-void ScriptingSystem::runScriptCommand(const cmd::ArgumentList& args) {
+void ScriptingSystem::runScriptCommand(const cmd::ArgumentList& args) 
+{
 	// Start the test script
 	if (args.empty()) return;
 
 	executeCommand(args[0].getString());
 }
 
-void ScriptingSystem::reloadScriptsCmd(const cmd::ArgumentList& args) {
+void ScriptingSystem::reloadScriptsCmd(const cmd::ArgumentList& args) 
+{
 	reloadScripts();
 }
 
-void ScriptingSystem::executeCommand(const std::string& name) {
+void ScriptingSystem::executeCommand(const std::string& name)
+{
 	// Sanity check
-	if (!_initialised) {
+	if (!_initialised)
+	{
 		rError() << "Cannot execute script command " << name
 			<< ", ScriptingSystem not initialised yet." << std::endl;
 		return;
@@ -228,16 +279,14 @@ void ScriptingSystem::executeCommand(const std::string& name) {
 	// Lookup the name
 	ScriptCommandMap::iterator found = _commands.find(name);
 
-	if (found == _commands.end()) {
+	if (found == _commands.end())
+	{
 		rError() << "Couldn't find command " << name << std::endl;
 		return;
 	}
 
-	// Set the execution flag in the global namespace
-	_mainObjects->globals["__executeCommand__"] = true;
-
 	// Execute the script file behind this command
-	executeScriptFile(found->second->getFilename());
+	executeScriptFile(found->second->getFilename(), true);
 }
 
 void ScriptingSystem::loadCommandScript(const std::string& scriptFilename)
@@ -245,29 +294,25 @@ void ScriptingSystem::loadCommandScript(const std::string& scriptFilename)
 	try
 	{
 		// Create a new dictionary for the initialisation routine
-		boost::python::dict locals;
+		py::dict locals;
 
 		// Disable the flag for initialisation, just for sure
 		locals["__executeCommand__"] = false;
 
 		// Attempt to run the specified script
-		boost::python::object ignored = boost::python::exec_file(
-			(_scriptPath + scriptFilename).c_str(),
-			_mainObjects->mainNamespace,
-			locals	// pass the new dictionary for the locals
-		);
+		py::eval_file(_scriptPath + scriptFilename, PythonModule::GetGlobals(), locals);
 
 		std::string cmdName;
 		std::string cmdDisplayName;
 
-		if (locals.has_key("__commandName__"))
+		if (locals.contains("__commandName__"))
 		{
-			cmdName = boost::python::extract<std::string>(locals["__commandName__"]);
+			cmdName = locals["__commandName__"].cast<std::string>();
 		}
 
-		if (locals.has_key("__commandDisplayName__"))
+		if (locals.contains("__commandDisplayName__"))
 		{
-			cmdDisplayName = boost::python::extract<std::string>(locals["__commandDisplayName__"]);
+			cmdDisplayName = locals["__commandDisplayName__"].cast<std::string>();
 		}
 
 		if (!cmdName.empty())
@@ -278,7 +323,7 @@ void ScriptingSystem::loadCommandScript(const std::string& scriptFilename)
 			}
 
 			// Successfully retrieved the command
-			ScriptCommandPtr cmd(new ScriptCommand(cmdName, cmdDisplayName, scriptFilename));
+			ScriptCommandPtr cmd = std::make_shared<ScriptCommand>(cmdName, cmdDisplayName, scriptFilename);
 
 			// Try to register this named command
 			std::pair<ScriptCommandMap::iterator, bool> result = _commands.insert(
@@ -286,27 +331,23 @@ void ScriptingSystem::loadCommandScript(const std::string& scriptFilename)
 			);
 
 			// Result.second is TRUE if the insert succeeded
-			if (result.second) {
+			if (result.second) 
+			{
 				rMessage() << "Registered script file " << scriptFilename
 					<< " as " << cmdName << std::endl;
 			}
-			else {
+			else 
+			{
 				rError() << "Error in " << scriptFilename << ": Script command "
 					<< cmdName << " has already been registered in "
 					<< _commands[cmdName]->getFilename() << std::endl;
 			}
 		}
 	}
-	catch (const boost::python::error_already_set&) {
-		rError() << "Script file " << scriptFilename
-			<< " is not a valid command." << std::endl;
-
-		// Dump the error to the console, this will invoke the PythonConsoleWriter
-		PyErr_Print();
-		PyErr_Clear();
-
-		// Python is usually not appending line feeds...
-		rMessage() << std::endl;
+	catch (const py::error_already_set& ex)
+	{
+		rError() << "Script file " << scriptFilename << " is not a valid command:" << std::endl;
+		rError() << ex.what() << std::endl;
 	}
 }
 
@@ -318,7 +359,8 @@ void ScriptingSystem::reloadScripts()
 	// Initialise the search's starting point
 	fs::path start = fs::path(_scriptPath) / "commands/";
 
-	if (!fs::exists(start)) {
+	if (!fs::exists(start))
+	{
 		rWarning() << "Couldn't find scripts folder: " << start.string() << std::endl;
 		return;
 	}
@@ -332,7 +374,7 @@ void ScriptingSystem::reloadScripts()
 		if (fs::is_directory(candidate)) continue;
 
 		std::string extension = os::getExtension(candidate.string());
-		boost::algorithm::to_lower(extension);
+		string::to_lower(extension);
 
 		if (extension != "py") continue;
 
@@ -345,7 +387,7 @@ void ScriptingSystem::reloadScripts()
 	// Re-create the script menu
 	_scriptMenu.reset();
 
-	_scriptMenu = ui::ScriptMenuPtr(new ui::ScriptMenu(_commands));
+	_scriptMenu = std::make_shared<ui::ScriptMenu>(_commands);
 }
 
 // RegisterableModule implementation
@@ -355,10 +397,12 @@ const std::string& ScriptingSystem::getName() const
 	return _name;
 }
 
-const StringSet& ScriptingSystem::getDependencies() const {
+const StringSet& ScriptingSystem::getDependencies() const
+{
 	static StringSet _dependencies;
 
-	if (_dependencies.empty()) {
+	if (_dependencies.empty())
+	{
 		_dependencies.insert(MODULE_RADIANT);
 		_dependencies.insert(MODULE_COMMANDSYSTEM);
 		_dependencies.insert(MODULE_UIMANAGER);
@@ -374,95 +418,60 @@ void ScriptingSystem::initialiseModule(const ApplicationContext& ctx)
 
 	// Subscribe to get notified as soon as Radiant is fully initialised
 	GlobalRadiant().signal_radiantStarted().connect(
-        sigc::mem_fun(this, &ScriptingSystem::initialise)
-    );
+		sigc::mem_fun(this, &ScriptingSystem::initialise)
+	);
 
 	// Construct the script path
 #if defined(POSIX) && defined(PKGLIBDIR)
-   _scriptPath = std::string(PKGLIBDIR) + "/scripts/";
+	_scriptPath = std::string(PKGLIBDIR) + "/scripts/";
 #else
 	_scriptPath = ctx.getRuntimeDataPath() + "scripts/";
 #endif
 
-	// start the python interpreter
-	Py_Initialize();
-
-	rMessage() << getName() << ": Python interpreter initialised." << std::endl;
-
-	// Initialise the boost::python objects
-	_mainObjects.reset(new BoostPythonMainObjects);
-
-	_mainObjects->mainModule = boost::python::import("__main__");
-	_mainObjects->mainNamespace = _mainObjects->mainModule.attr("__dict__");
-
-	try {
-		// Construct the console writer interface
-		PythonConsoleWriterClass consoleWriter("PythonConsoleWriter", boost::python::init<bool, std::string&>());
-		consoleWriter.def("write", &PythonConsoleWriter::write);
-
-		// Declare the interface to python
-		_mainObjects->mainNamespace["PythonConsoleWriter"] = consoleWriter;
-
-		// Redirect stdio output to our local ConsoleWriter instances
-		boost::python::import("sys").attr("stderr") = boost::python::ptr(&_errorWriter);
-		boost::python::import("sys").attr("stdout") = boost::python::ptr(&_outputWriter);
-	}
-	catch (const boost::python::error_already_set&) {
-		// Dump the error to the console, this will invoke the PythonConsoleWriter
-		PyErr_Print();
-		PyErr_Clear();
-
-		// Python is usually not appending line feeds...
-		rMessage() << std::endl;
-	}
-
-	// Declare the std::vector<std::string> object to Python, this is used several times
-	_mainObjects->mainNamespace["StringVector"] = boost::python::class_< std::vector<std::string> >("StringVector")
-		.def(boost::python::vector_indexing_suite<std::vector<std::string>, true>())
-	;
+	// When Python asks for the object, let's register our interfaces to the py::module
+	PythonModule::RegisterToPython(
+		std::bind(&ScriptingSystem::addInterfacesToModule, this, std::placeholders::_1, std::placeholders::_2));
 
 	// Add the built-in interfaces (the order is important, as we don't have dependency-resolution yet)
-	addInterface("Math", MathInterfacePtr(new MathInterface));
-	addInterface("GameManager", GameInterfacePtr(new GameInterface));
-	addInterface("CommandSystem", CommandSystemInterfacePtr(new CommandSystemInterface));
-	addInterface("SceneGraph", SceneGraphInterfacePtr(new SceneGraphInterface));
-	addInterface("GlobalRegistry", RegistryInterfacePtr(new RegistryInterface));
-	addInterface("GlobalEntityClassManager", EClassManagerInterfacePtr(new EClassManagerInterface));
-	addInterface("GlobalSelectionSystem", SelectionInterfacePtr(new SelectionInterface));
-	addInterface("Brush", BrushInterfacePtr(new BrushInterface));
-	addInterface("Patch", PatchInterfacePtr(new PatchInterface));
-	addInterface("Entity", EntityInterfacePtr(new EntityInterface));
-	addInterface("Radiant", RadiantInterfacePtr(new RadiantInterface));
-	addInterface("Map", MapInterfacePtr(new MapInterface));
-	addInterface("FileSystem", FileSystemInterfacePtr(new FileSystemInterface));
-	addInterface("Grid", GridInterfacePtr(new GridInterface));
-	addInterface("ShaderSystem", ShaderSystemInterfacePtr(new ShaderSystemInterface));
-	addInterface("Model", ModelInterfacePtr(new ModelInterface));
-	addInterface("ModelSkinCacheInterface", ModelSkinCacheInterfacePtr(new ModelSkinCacheInterface));
-	addInterface("SoundManager", SoundManagerInterfacePtr(new SoundManagerInterface));
-	addInterface("DialogInterface", DialogManagerInterfacePtr(new DialogManagerInterface));
-	addInterface("SelectionSetInterface", SelectionSetInterfacePtr(new SelectionSetInterface));
+	addInterface("Math", std::make_shared<MathInterface>());
+	addInterface("GameManager", std::make_shared<GameInterface>());
+	addInterface("CommandSystem", std::make_shared<CommandSystemInterface>());
+	addInterface("SceneGraph", std::make_shared<SceneGraphInterface>());
+	addInterface("GlobalRegistry", std::make_shared<RegistryInterface>());
+	addInterface("GlobalEntityClassManager", std::make_shared<EClassManagerInterface>());
+	addInterface("GlobalSelectionSystem", std::make_shared<SelectionInterface>());
+	addInterface("Brush", std::make_shared<BrushInterface>());
+	addInterface("Patch", std::make_shared<PatchInterface>());
+	addInterface("Entity", std::make_shared<EntityInterface>());
+	addInterface("Radiant", std::make_shared<RadiantInterface>());
+	addInterface("Map", std::make_shared<MapInterface>());
+	addInterface("FileSystem", std::make_shared<FileSystemInterface>());
+	addInterface("Grid", std::make_shared<GridInterface>());
+	addInterface("ShaderSystem", std::make_shared<ShaderSystemInterface>());
+	addInterface("Model", std::make_shared<ModelInterface>());
+	addInterface("ModelSkinCacheInterface", std::make_shared<ModelSkinCacheInterface>());
+	addInterface("SoundManager", std::make_shared<SoundManagerInterface>());
+	addInterface("DialogInterface", std::make_shared<DialogManagerInterface>());
+	addInterface("SelectionSetInterface", std::make_shared<SelectionSetInterface>());
+	addInterface("SelectionGroupInterface", std::make_shared<SelectionGroupInterface>());
 
 	GlobalCommandSystem().addCommand(
 		"RunScript",
-		boost::bind(&ScriptingSystem::runScriptFile, this, _1),
+		std::bind(&ScriptingSystem::runScriptFile, this, std::placeholders::_1),
 		cmd::ARGTYPE_STRING
 	);
 
 	GlobalCommandSystem().addCommand(
 		"ReloadScripts",
-		boost::bind(&ScriptingSystem::reloadScriptsCmd, this, _1)
+		std::bind(&ScriptingSystem::reloadScriptsCmd, this, std::placeholders::_1)
 	);
 
 	GlobalCommandSystem().addCommand(
 		"RunScriptCommand",
-		boost::bind(&ScriptingSystem::runScriptCommand, this, _1),
+		std::bind(&ScriptingSystem::runScriptCommand, this, std::placeholders::_1),
 		cmd::ARGTYPE_STRING
 	);
 
-	// Search script folder for commands
-	reloadScripts();
-
 	// Bind the reloadscripts command to the menu
 	GlobalEventManager().addCommand("ReloadScripts", "ReloadScripts");
 
@@ -482,24 +491,28 @@ void ScriptingSystem::shutdownModule()
 {
 	rMessage() << getName() << "::shutdownModule called." << std::endl;
 
-	_scriptMenu = ui::ScriptMenuPtr();
+	_scriptMenu.reset();
+
+	_initialised = false;
 
 	// Clear the buffer so that nodes finally get destructed
 	SceneNodeBuffer::Instance().clear();
-    
-    _commands.clear();
+
+	_commands.clear();
 
 	_scriptPath.clear();
 
 	// Free all interfaces
 	_interfaces.clear();
 
-	_initialised = false;
-
-	// Clear the boost::python::objects
-	_mainObjects.reset();
+	PythonModule::Clear();
 
+	// The finalize_interpreter() function is not available in older versions
+#ifdef DR_PYBIND_HAS_EMBED_H
+	py::finalize_interpreter();
+#else 
 	Py_Finalize();
+#endif
 }
 
 } // namespace script
