@@ -1,8 +1,8 @@
 #pragma once
 
-#include <boost/python.hpp>
 #include <map>
 #include <vector>
+#include <pybind11/pybind11.h>
 
 #include "iscript.h"
 #include "PythonConsoleWriter.h"
@@ -11,7 +11,10 @@
 #include "ScriptCommand.h"
 #include "ScriptMenu.h"
 
-namespace script {
+namespace py = pybind11;
+
+namespace script 
+{
 
 // Forward declaration
 class StartupListener;
@@ -33,14 +36,6 @@ private:
 	typedef std::vector<NamedInterface> Interfaces;
 	Interfaces _interfaces;
 
-	struct BoostPythonMainObjects
-	{
-		boost::python::object mainModule;
-		boost::python::object mainNamespace;
-		boost::python::dict globals;
-	};
-	std::unique_ptr<BoostPythonMainObjects> _mainObjects;
-
 	// The path where the script files are hosted
 	std::string _scriptPath;
 
@@ -53,7 +48,7 @@ public:
 	ScriptingSystem();
 
 	// Adds a script interface to this system
-	void addInterface(const std::string& name, const IScriptInterfacePtr& iface);
+	void addInterface(const std::string& name, const IScriptInterfacePtr& iface) override;
 
 	// (Re)loads all scripts from the scripts/ folder
 	void reloadScriptsCmd(const cmd::ArgumentList& args);
@@ -74,23 +69,27 @@ public:
 	void runScriptCommand(const cmd::ArgumentList& args);
 
 	// Executes a script file
-	void executeScriptFile(const std::string& filename);
+	void executeScriptFile(const std::string& filename) override;
 
 	// Execute the given python script string
-	ExecutionResultPtr executeString(const std::string& scriptString);
+	ExecutionResultPtr executeString(const std::string& scriptString) override;
 
 	// Runs the named command (or rather the .py file behind it)
 	void executeCommand(const std::string& name);
 
 	// RegisterableModule implementation
-	const std::string& getName() const;
-	const StringSet& getDependencies() const;
-	void initialiseModule(const ApplicationContext& ctx);
-	void shutdownModule();
+	const std::string& getName() const override;
+	const StringSet& getDependencies() const override;
+	void initialiseModule(const ApplicationContext& ctx) override;
+	void shutdownModule() override;
 
 private:
+	void executeScriptFile(const std::string& filename, bool setExecuteCommandAttr);
+
 	bool interfaceExists(const std::string& name);
 
+	void addInterfacesToModule(py::module& mod, py::dict&);
+
 	void reloadScripts();
 
 	void loadCommandScript(const std::string& scriptFilename);
