@@ -10,8 +10,7 @@
 #include "TableDefinition.h"
 
 #include <iostream>
-#include <boost/algorithm/string/replace.hpp>
-#include <boost/algorithm/string/case_conv.hpp>
+#include "string/replace.h"
 
 /* FORWARD DECLS */
 
@@ -63,7 +62,7 @@ void ShaderFileLoader::parseShaderFile(std::istream& inStr,
 			continue; // skip particle definition
 		}
 
-		boost::algorithm::replace_all(block.name, "\\", "/"); // use forward slashes
+		string::replace_all(block.name, "\\", "/"); // use forward slashes
 
 		ShaderTemplatePtr shaderTemplate(new ShaderTemplate(block.name, block.contents));
 
@@ -93,7 +92,7 @@ void ShaderFileLoader::parseFiles()
 
 		if (_currentOperation)
 		{
-			_currentOperation->setMessage((boost::format(_("Parsing material file %s")) % fullPath).str());
+			_currentOperation->setMessage(fmt::format(_("Parsing material file {0}"), fullPath));
 
 			float progress = static_cast<float>(i) / _files.size();
 			_currentOperation->setProgress(progress);
