@@ -8,9 +8,8 @@
 #include "string/convert.h"
 #include "parser/DefTokeniser.h"
 
-#include <boost/lexical_cast.hpp>
-#include <boost/algorithm/string/case_conv.hpp>
-#include <boost/algorithm/string/trim.hpp>
+#include "string/case_conv.h"
+#include "string/trim.h"
 #include <iostream>
 
 #include "ShaderExpression.h"
@@ -155,7 +154,7 @@ bool ShaderTemplate::parseShaderFlags(parser::DefTokeniser& tokeniser,
 		else // no special sort keyword, try to parse the numeric value
 		{
 			//  Strip any quotes
-			boost::algorithm::trim_if(sortVal, boost::algorithm::is_any_of("\""));
+			string::trim(sortVal, "\"");
 
 			_sortReq = string::convert<int>(sortVal, SORT_UNDEFINED); // fall back to UNDEFINED in case of parsing failures
 		}
@@ -232,7 +231,7 @@ bool ShaderTemplate::parseShaderFlags(parser::DefTokeniser& tokeniser,
 	else if (token == "deform")
 	{
 		std::string type = tokeniser.nextToken();
-		boost::algorithm::to_lower(type);
+		string::to_lower(type);
 
 		if (type == "sprite")
 		{
@@ -292,7 +291,7 @@ bool ShaderTemplate::parseShaderFlags(parser::DefTokeniser& tokeniser,
 		// Skip over this renderbump directive
 		// Syntax: renderBump [-size <width> <height>] [-aa <0/1/2>] [-trace <0.01 - 1.0>] <normalMapImage> <highPolyModel>
 		std::string next = tokeniser.nextToken();
-		boost::algorithm::to_lower(next);
+		string::to_lower(next);
 
 		// Skip over the optional args
 		while (next.length() > 0 && next[0] == '-')
@@ -311,7 +310,7 @@ bool ShaderTemplate::parseShaderFlags(parser::DefTokeniser& tokeniser,
 			}
 
 			next = tokeniser.nextToken();
-			boost::algorithm::to_lower(next);
+			string::to_lower(next);
 		}
 
 		// The map token is already loaded in "next", skip the highpoly model name
@@ -322,7 +321,7 @@ bool ShaderTemplate::parseShaderFlags(parser::DefTokeniser& tokeniser,
 		// Skip over this renderbump directive
 		// Syntax: RenderBumpFlat [-size <width> <height>] <modelfile>
 		std::string next = tokeniser.nextToken();
-		boost::algorithm::to_lower(next);
+		string::to_lower(next);
 
 		// Skip over the optional args
 		if (next == "-size")
@@ -364,9 +363,9 @@ bool ShaderTemplate::parseLightKeywords(parser::DefTokeniser& tokeniser, const s
 
 		try
 		{
-			_spectrum = boost::lexical_cast<int>(value);
+			_spectrum = std::stoi(value);
 		}
-		catch (boost::bad_lexical_cast& e)
+		catch (std::logic_error& e)
 		{
 			rWarning() << "Expect integer number as spectrum value, found " << 
 				value << ": " << e.what() << std::endl;
@@ -416,7 +415,7 @@ bool ShaderTemplate::parseBlendType(parser::DefTokeniser& tokeniser, const std::
 {
     if (token == "blend")
     {
-        std::string blendType = boost::algorithm::to_lower_copy(tokeniser.nextToken());
+        std::string blendType = string::to_lower_copy(tokeniser.nextToken());
 
         if (blendType == "diffusemap")
 		{
@@ -514,7 +513,7 @@ bool ShaderTemplate::parseBlendMaps(parser::DefTokeniser& tokeniser, const std::
 	else if (token == "videomap")
     {
 		std::string nextToken = tokeniser.nextToken();
-		boost::algorithm::to_lower(nextToken);
+		string::to_lower(nextToken);
 
 		if (nextToken == "loop")
 		{
@@ -534,10 +533,10 @@ bool ShaderTemplate::parseBlendMaps(parser::DefTokeniser& tokeniser, const std::
 	{
 		try
 		{
-			string::convert<int>(tokeniser.nextToken());
-			string::convert<int>(tokeniser.nextToken());
+			std::stoi(tokeniser.nextToken());
+			std::stoi(tokeniser.nextToken());
 		}
-		catch (boost::bad_lexical_cast& e)
+		catch (std::logic_error& e)
 		{
 			rWarning() << "Error parsing remoteRenderMap. Expected two integers: " 
 				<< e.what() << std::endl;
@@ -547,10 +546,10 @@ bool ShaderTemplate::parseBlendMaps(parser::DefTokeniser& tokeniser, const std::
 	{
 		try
 		{
-			string::convert<int>(tokeniser.nextToken());
-			string::convert<int>(tokeniser.nextToken());
+			std::stoi(tokeniser.nextToken());
+			std::stoi(tokeniser.nextToken());
 		}
-		catch (boost::bad_lexical_cast& e)
+		catch (std::invalid_argument& e)
 		{
 			rWarning() << "Error parsing mirrorRenderMap. Expected two integers: "
 				<< e.what() << std::endl;
@@ -747,7 +746,7 @@ bool ShaderTemplate::parseStageModifiers(parser::DefTokeniser& tokeniser,
 		int mapNum = string::convert<int>(tokeniser.nextToken());
 
 		std::string next = tokeniser.peek();
-		boost::algorithm::to_lower(next);
+		string::to_lower(next);
 
 		// These are all valid option keywords
 		while (next == "cubemap" || next == "cameracubemap" || next == "nearest" ||
@@ -758,7 +757,7 @@ bool ShaderTemplate::parseStageModifiers(parser::DefTokeniser& tokeniser,
 			tokeniser.nextToken();
 
 			next = tokeniser.peek();
-			boost::algorithm::to_lower(next);
+			string::to_lower(next);
 		}
 
 		// Get the map expression (but don't really use it)
@@ -1176,7 +1175,7 @@ void ShaderTemplate::parseDefinition()
             }
             else
 			{
-				boost::algorithm::to_lower(token);
+				string::to_lower(token);
 
                 switch (level)
 				{
