@@ -13,6 +13,7 @@
 #include "FilterMenu.h"
 #include "wxutil/dialog/MessageBox.h"
 
+#include "animationpreview/MD5AnimationViewer.h"
 #include "LocalBitmapArtProvider.h"
 
 #include <wx/artprov.h>
@@ -100,6 +101,9 @@ void UIManager::initialiseModule(const ApplicationContext& ctx)
 	_toolbarManager.initialise();
 	ColourSchemeManager::Instance().loadColourSchemes();
 
+	GlobalCommandSystem().addCommand("AnimationPreview", MD5AnimationViewer::Show);
+	GlobalEventManager().addCommand("AnimationPreview", "AnimationPreview");
+
 	GlobalCommandSystem().addCommand("EditColourScheme", ColourSchemeEditor::DisplayDialog);
 	GlobalEventManager().addCommand("EditColourScheme", "EditColourScheme");
 
@@ -124,24 +128,14 @@ void UIManager::initialiseModule(const ApplicationContext& ctx)
 
 void UIManager::shutdownModule()
 {
-    // Free the XmlResources instance
-    // (I intermittently hit debug heap breakpoints when wx is 
-    //  deleting XRC XML resource memory, so let's attempt to fix that this way.)
-    //delete wxXmlResource::Set(nullptr);
+	_menuManager.clear();
 }
 
 } // namespace ui
 
 extern "C" void DARKRADIANT_DLLEXPORT RegisterModule(IModuleRegistry& registry)
 {
+	module::performDefaultInitialisation(registry);
+
 	registry.registerModule(ui::UIManagerPtr(new ui::UIManager));
-
-	// Initialise the streams using the given application context
-	module::initialiseStreams(registry.getApplicationContext());
-
-	// Remember the reference to the ModuleRegistry
-	module::RegistryReference::Instance().setRegistry(registry);
-
-	// Set up the assertion handler
-	GlobalErrorHandler() = registry.getApplicationContext().getErrorHandlingFunction();
 }
