@@ -1,36 +1,46 @@
 #include "DirectoryArchive.h"
 
-#include "archivelib.h"
+#include "gamelib.h"
 #include "UnixPath.h"
 #include "os/file.h"
 #include "os/dir.h"
 #include "os/fs.h"
 #include <vector>
 
+#include "DirectoryArchiveFile.h"
+#include "DirectoryArchiveTextFile.h"
+
 DirectoryArchive::DirectoryArchive(const std::string& root) :
-	_root(root)
+	_root(root),
+	_modName(game::current::getModPath(_root))
 {}
 
-ArchiveFilePtr DirectoryArchive::openFile(const std::string& name) {
+ArchiveFilePtr DirectoryArchive::openFile(const std::string& name) 
+{
 	UnixPath path(_root);
 	path.push_filename(name);
 
-	DirectoryArchiveFilePtr file(new DirectoryArchiveFile(name, path));
+	std::shared_ptr<archive::DirectoryArchiveFile> file = 
+		std::make_shared<archive::DirectoryArchiveFile>(name, path);
 
-	if (!file->failed()) {
+	if (!file->failed())
+	{
 		return file;
 	}
 
 	return ArchiveFilePtr();
 }
 
-ArchiveTextFilePtr DirectoryArchive::openTextFile(const std::string& name) {
+ArchiveTextFilePtr DirectoryArchive::openTextFile(const std::string& name)
+{
 	UnixPath path(_root);
 	path.push_filename(name);
 
-	DirectoryArchiveTextFilePtr file(new DirectoryArchiveTextFile(name, _root, path));
+	std::shared_ptr<archive::DirectoryArchiveTextFile> file = 
+		std::make_shared<archive::DirectoryArchiveTextFile>(name, _modName, path);
 
-	if (!file->failed()) {
+	if (!file->failed()) 
+	{
 		return file;
 	}
 
@@ -44,13 +54,13 @@ bool DirectoryArchive::containsFile(const std::string& name)
 	return os::fileIsReadable(path);
 }
 
-#include <iostream>
-
-void DirectoryArchive::forEachFile(VisitorFunc visitor, const std::string& root) {
+void DirectoryArchive::traverse(Visitor& visitor, const std::string& root)
+{
 	// Initialise the search's starting point
 	fs::path start(_root + root);
 
-	if (!fs::exists(start)) {
+	if (!fs::exists(start))
+	{
 		return;
 	}
 
@@ -66,7 +76,7 @@ void DirectoryArchive::forEachFile(VisitorFunc visitor, const std::string& root)
 		if (fs::is_directory(candidate))
 		{
 			// Check if we should traverse further
-			if (visitor.directory(candidateStr.substr(rootLen), os::getDepth(it)+1))
+			if (visitor.visitDirectory(candidateStr.substr(rootLen), os::getDepth(it)+1))
 			{
 				// Visitor returned true, prevent going deeper into it
 				os::disableRecursionPending(it);
@@ -75,7 +85,7 @@ void DirectoryArchive::forEachFile(VisitorFunc visitor, const std::string& root)
 		else
 		{
 			// File
-			visitor.file(candidateStr.substr(rootLen));
+			visitor.visitFile(candidateStr.substr(rootLen));
 		}
 	}
 }
