@@ -56,7 +56,7 @@ public:
 	void testSelect(Selector& selector, SelectionTest& test) {
 		SelectionIntersection best;
 		m_vertex->testSelect(test, best);
-		if (best.valid()) {
+		if (best.isValid()) {
 			Selector_add(selector, *this, best);
 		}
 	}
