@@ -47,14 +47,14 @@ public:
     void render(const Matrix4& modelview, const Matrix4& projection);
 
     // RenderableCollector implementation
-    void SetState(const ShaderPtr& shader, EStyle style);
-    bool supportsFullMaterials() const;
-    void PushState();
-    void PopState();
+    void SetState(const ShaderPtr& shader, EStyle style) override;
+    bool supportsFullMaterials() const override;
+    void PushState() override;
+    void PopState() override;
 	void setHighlightFlag(Highlight::Flags flags, bool enabled) override;
-    void setLights(const LightList& lights);
-    void addRenderable(const OpenGLRenderable& renderable, const Matrix4& world);
+    void setLights(const LightList& lights) override;
+    void addRenderable(const OpenGLRenderable& renderable, const Matrix4& world) override;
 	void addRenderable(const OpenGLRenderable& renderable,
                        const Matrix4& world,
-                       const IRenderEntity& entity);
+                       const IRenderEntity& entity) override;
 };
