@@ -2,6 +2,7 @@
 
 #include "i18n.h"
 #include <ostream>
+#include <fstream>
 #include "itextstream.h"
 #include "iscenegraph.h"
 #include "idialogmanager.h"
@@ -19,7 +20,7 @@
 #include "igame.h"
 
 #include "registry/registry.h"
-#include "stream/textfilestream.h"
+#include "stream/TextFileInputStream.h"
 #include "entitylib.h"
 #include "gamelib.h"
 #include "os/path.h"
@@ -37,8 +38,10 @@
 #include "map/RootNode.h"
 #include "map/MapResource.h"
 #include "map/algorithm/Merge.h"
+#include "map/algorithm/Export.h"
 #include "map/algorithm/Traverse.h"
 #include "map/algorithm/MapExporter.h"
+#include "model/ModelExporter.h"
 #include "map/algorithm/Skins.h"
 #include "ui/mru/MRU.h"
 #include "ui/mainframe/ScreenUpdateBlocker.h"
@@ -50,7 +53,7 @@
 #include "modulesystem/StaticModule.h"
 #include "RenderableAasFile.h"
 
-#include <boost/format.hpp>
+#include <fmt/format.h>
 #include "algorithm/ChildPrimitives.h"
 
 namespace map 
@@ -331,12 +334,7 @@ void Map::gotoStartPosition()
 				origin.z() += game::current::getValue<float>(GKEY_PLAYER_HEIGHT);
 
                 // Check for an angle key, and use it if present
-                try {
-                    angles[ui::CAMERA_YAW] = boost::lexical_cast<float>(playerStart->getKeyValue("angle"));
-                }
-                catch (boost::bad_lexical_cast&) {
-                    angles[ui::CAMERA_YAW] = 0;
-                }
+                angles[ui::CAMERA_YAW] = string::convert<float>(playerStart->getKeyValue("angle"), 0);
             }
         }
     }
@@ -436,7 +434,7 @@ bool Map::save(const MapFormatPtr& mapFormat)
 	catch (std::runtime_error& ex)
 	{
 		wxutil::Messagebox::ShowError(
-			(boost::format(_("Failure running map pre-save event:\n%s")) % ex.what()).str());
+			fmt::format(_("Failure running map pre-save event:\n{0}"), ex.what()));
 	}
 
     // Store the camview position into worldspawn
@@ -577,30 +575,24 @@ bool Map::saveSelected(const std::string& filename, const MapFormatPtr& mapForma
 
 std::string Map::getSaveConfirmationText() const
 {
-    std::string primaryText = (boost::format(
-        _("Save changes to map \"%s\"\nbefore closing?")) % _mapName
-    ).str();
+    std::string primaryText = fmt::format(_("Save changes to map \"{0}\"\nbefore closing?"), _mapName);
 
     // Display "x seconds" or "x minutes"
     int seconds = static_cast<int>(_mapSaveTimer.Time() / 1000);
     std::string timeString;
     if (seconds > 120)
     {
-        timeString = (boost::format(_("%d minutes")) % (seconds / 60)).str();
+        timeString = fmt::format(_("{0:d} minutes"), (seconds / 60));
     }
     else
     {
-        timeString = (boost::format(_("%d seconds")) % seconds).str();
+        timeString = fmt::format(_("{0:d} seconds"), seconds);
     }
 
-    std::string secondaryText = (boost::format(
-        _("If you don't save, changes from the last %s\nwill be lost.")) %
-        timeString
-    ).str();
+    std::string secondaryText = fmt::format(
+        _("If you don't save, changes from the last {0}\nwill be lost."), timeString);
 
-    std::string confirmText = (boost::format("%s\n\n%s")
-		% primaryText % secondaryText
-    ).str();
+    std::string confirmText = fmt::format("{0}\n\n{1}", primaryText, secondaryText);
 
     return confirmText;
 }
@@ -652,7 +644,7 @@ bool Map::saveAs()
     if (_saveInProgress) return false; // safeguard
 
     MapFileSelection fileInfo =
-        MapFileManager::getMapFileSelection(false, _("Save Map"), "map", getMapName());
+        MapFileManager::getMapFileSelection(false, _("Save Map"), filetype::TYPE_MAP, getMapName());
 
 	if (!fileInfo.fullPath.empty())
 	{
@@ -692,7 +684,7 @@ bool Map::saveCopyAs()
     }
 
 	MapFileSelection fileInfo =
-        MapFileManager::getMapFileSelection(false, _("Save Copy As..."), "map", _lastCopyMapName);
+        MapFileManager::getMapFileSelection(false, _("Save Copy As..."), filetype::TYPE_MAP, _lastCopyMapName);
 
 	if (!fileInfo.fullPath.empty())
 	{
@@ -710,7 +702,7 @@ bool Map::saveCopyAs()
 void Map::loadPrefabAt(const Vector3& targetCoords)
 {
     /*MapFileSelection fileInfo =
-        MapFileManager::getMapFileSelection(true, _("Load Prefab"), "prefab");*/
+        MapFileManager::getMapFileSelection(true, _("Load Prefab"), filetype::TYPE_PREFAB);*/
 
 	ui::PrefabSelector::Result result = ui::PrefabSelector::ChoosePrefab();
 
@@ -767,6 +759,11 @@ void Map::registerCommands()
     GlobalCommandSystem().addCommand("SaveMapCopyAs", Map::saveMapCopyAs);
     GlobalCommandSystem().addCommand("SaveSelected", Map::exportMap);
 	GlobalCommandSystem().addCommand("ReloadSkins", map::algorithm::reloadSkins);
+	GlobalCommandSystem().addCommand("ExportSelectedAsModel", map::algorithm::exportSelectedAsModelCmd,
+		cmd::Signature(cmd::ARGTYPE_STRING, cmd::ARGTYPE_STRING, 
+					   cmd::ARGTYPE_INT|cmd::ARGTYPE_OPTIONAL, 
+					   cmd::ARGTYPE_INT|cmd::ARGTYPE_OPTIONAL, 
+					   cmd::ARGTYPE_INT|cmd::ARGTYPE_OPTIONAL));
 
     GlobalEventManager().addCommand("NewMap", "NewMap");
     GlobalEventManager().addCommand("OpenMap", "OpenMap");
@@ -778,6 +775,7 @@ void Map::registerCommands()
     GlobalEventManager().addCommand("SaveMapCopyAs", "SaveMapCopyAs");
     GlobalEventManager().addCommand("SaveSelected", "SaveSelected");
 	GlobalEventManager().addCommand("ReloadSkins", "ReloadSkins");
+	GlobalEventManager().addCommand("ExportSelectedAsModel", "ExportSelectedAsModel");
 }
 
 // Static command targets
@@ -796,7 +794,7 @@ void Map::openMap(const cmd::ArgumentList& args)
         return;
 
     // Get the map file name to load
-    MapFileSelection fileInfo = MapFileManager::getMapFileSelection(true, _("Open map"), "map");
+    MapFileSelection fileInfo = MapFileManager::getMapFileSelection(true, _("Open map"), filetype::TYPE_MAP);
 
     if (!fileInfo.fullPath.empty())
 	{
@@ -810,7 +808,7 @@ void Map::openMap(const cmd::ArgumentList& args)
 void Map::importMap(const cmd::ArgumentList& args)
 {
     MapFileSelection fileInfo =
-        MapFileManager::getMapFileSelection(true, _("Import map"), "map");
+        MapFileManager::getMapFileSelection(true, _("Import map"), filetype::TYPE_MAP);
 
     if (!fileInfo.fullPath.empty())
     {
@@ -839,7 +837,7 @@ void Map::saveMap(const cmd::ArgumentList& args)
 void Map::exportMap(const cmd::ArgumentList& args)
 {
     MapFileSelection fileInfo =
-        MapFileManager::getMapFileSelection(false, _("Export selection"), "map");
+        MapFileManager::getMapFileSelection(false, _("Export selection"), filetype::TYPE_MAP);
 
 	if (!fileInfo.fullPath.empty())
 	{
@@ -854,7 +852,7 @@ void Map::loadPrefab(const cmd::ArgumentList& args) {
 void Map::saveSelectedAsPrefab(const cmd::ArgumentList& args)
 {
     MapFileSelection fileInfo =
-        MapFileManager::getMapFileSelection(false, _("Save selected as Prefab"), "prefab");
+        MapFileManager::getMapFileSelection(false, _("Save selected as Prefab"), filetype::TYPE_PREFAB);
 
 	if (!fileInfo.fullPath.empty())
     {
@@ -935,7 +933,7 @@ void Map::importSelected(std::istream& in)
     catch (IMapReader::FailureException& e)
     {
         wxutil::Messagebox::ShowError(
-            (boost::format(_("Failure reading map from clipboard:\n%s")) % e.what()).str());
+            fmt::format(_("Failure reading map from clipboard:\n{0}"), e.what()));
 
         // Clear out the root node, otherwise we end up with half a map
         scene::NodeRemover remover;
@@ -957,7 +955,8 @@ void Map::exportSelected(std::ostream& out)
 }
 
 // RegisterableModule implementation
-const std::string& Map::getName() const {
+const std::string& Map::getName() const
+{
     static std::string _name(MODULE_MAP);
     return _name;
 }
@@ -971,6 +970,7 @@ const StringSet& Map::getDependencies() const
         _dependencies.insert(MODULE_RADIANT);
 		_dependencies.insert(MODULE_GAMEMANAGER);
 		_dependencies.insert(MODULE_SCENEGRAPH);
+		_dependencies.insert(MODULE_FILETYPES);
     }
 
     return _dependencies;
