@@ -5,21 +5,27 @@
 #include "imapformat.h"
 #include "inamespace.h"
 #include "imapresource.h"
+#include "iscenegraph.h"
 #include "icommandsystem.h"
 #include "imodule.h"
 #include "math/Vector3.h"
 
-#include "StartupMapLoader.h"
+#include "model/ScaledModelExporter.h"
 
 #include <sigc++/signal.h>
 #include <wx/stopwatch.h>
 
 class TextInputStream;
 
-namespace map {
+namespace map
+{
+
+class MapPositionManager;
+class StartupMapLoader;
 
 class Map :
-	public IMap
+	public IMap,
+	public scene::Graph::Observer
 {
 	// The map name
 	std::string _mapName;
@@ -37,7 +43,9 @@ class Map :
 	bool _saveInProgress;
 
 	// A local helper object, observing the radiant module
-	StartupMapLoaderPtr _startupMapLoader;
+	std::unique_ptr<StartupMapLoader> _startupMapLoader;
+	ScaledModelExporter _scaledModelExporter;
+	std::unique_ptr<MapPositionManager> _mapPositionManager;
 
     // Map save timer, for displaying "changes from last n minutes will be lost"
     // messages
@@ -60,6 +68,10 @@ public:
 	virtual const std::string& getName() const override;
 	virtual const StringSet& getDependencies() const override;
 	virtual void initialiseModule(const ApplicationContext& ctx) override;
+	virtual void shutdownModule() override;
+
+	// Gets called when a node is removed from the scenegraph
+	virtual void onSceneNodeErase(const scene::INodePtr& node) override;
 
 	/** greebo: Returns true if the map has not been named yet.
 	 */
@@ -72,7 +84,7 @@ public:
 
 	/** greebo: Returns the name of this class
 	 */
-	std::string getMapName() const;
+	std::string getMapName() const override;
 
 	/**
 	 * greebo: Saves the current map, doesn't ask for any filenames,
