@@ -3,28 +3,27 @@
 #include <vector>
 #include "irender.h"
 #include "imap.h"
+#include "imodule.h"
 #include "icommandsystem.h"
 #include "irenderable.h"
 #include "math/Vector3.h"
+#include "render.h"
 
 namespace map 
 {
 
 class PointFile :
-	public Renderable,
-	public OpenGLRenderable
+	public RegisterableModule,
+	public Renderable
 {
+private:
 	// Vector of point coordinates
-	typedef std::vector<Vector3> VectorList;
-	VectorList _points;
-
+	RenderablePointVector _points;
+	
 	// Holds the current position in the point file chain
-	VectorList::iterator _curPos;
+	std::size_t _curPos;
 
-	// GL display list pointer for rendering the point path
-	int _displayList;
-
-	static ShaderPtr _renderstate;
+	ShaderPtr _renderstate;
 
 public:
 	// Constructor
@@ -33,30 +32,10 @@ public:
 	// Destructor
 	virtual ~PointFile() {}
 
-	/** greebo: Accessor method containing the singleton instance.
-	 */
-	static PointFile& Instance();
-
-	/** greebo: This releases the shader and detaches this class from
-	 * 			the shadercache.
-	 */
-	void destroy();
-
 	// Query whether the point path is currently visible
 	bool isVisible() const;
 
   	/*
-	 * Toggle the status of the pointfile rendering. If the pointfile must be
-	 * shown, the file is parsed automatically.
-	 */
-	void show(bool show);
-
-	/*
-	 * OpenGL render function (back-end).
-	 */
-	void render(const RenderInfo& info) const;
-
-	/*
 	 * Solid renderable submission function (front-end)
 	 */
 	void renderSolid(RenderableCollector& collector, const VolumeTest& volume) const override;
@@ -74,33 +53,41 @@ public:
 		return Highlight::NoHighlight;
 	}
 
-	/** greebo: This sets the camera position to the next/prev leak spot.
-	 *
+	const std::string& getName() const override;
+	const StringSet& getDependencies() const override;
+	void initialiseModule(const ApplicationContext& ctx) override;
+	void shutdownModule() override;
+
+private:
+	// Registers the events to the EventManager
+	void registerCommands();
+
+	/*
+	 * Toggle the status of the pointfile rendering. If the pointfile must be
+	 * shown, the file is parsed automatically.
+	 */
+	void show(bool show);
+
+	/**
+	 * greebo: Clears the point file vector, which is the same as hiding it.
+	 */
+	void clear();
+
+	/** 
+	 * greebo: This sets the camera position to the next/prev leak spot.
 	 * @forward: pass true to set to the next leak spot, false for the previous
 	 */
 	void advance(bool forward);
 
-	/** greebo: Clears the point file vector and hides it, if applicable.
-	 */
-	void clear();
-
-	// Registers the events to the EventManager
-	static void registerCommands();
-
-	// Static command targets, these re-route the call to the static instance
-	static void nextLeakSpot(const cmd::ArgumentList& args);
-	static void prevLeakSpot(const cmd::ArgumentList& args);
-
+	// command targets
 	// Toggles visibility of the point file line
-	static void toggle(const cmd::ArgumentList& args);
+	void toggle(const cmd::ArgumentList& args);
+	void nextLeakSpot(const cmd::ArgumentList& args);
+	void prevLeakSpot(const cmd::ArgumentList& args);
 
-private:
 	// Parse the current pointfile and read the vectors into the point list
 	void parse();
 
-	// Generates the OpenGL displaylist from the point vector
-	void generateDisplayList();
-
 	void onMapEvent(IMap::MapEvent ev);
 };
 
