@@ -5,11 +5,13 @@
 #include "imodelcache.h"
 #include "icommandsystem.h"
 
-namespace model {
+namespace model
+{
 
 class ModelCache :
 	public IModelCache
 {
+private:
 	// The container maps model names to instances
 	typedef std::map<std::string, IModelPtr> ModelMap;
 	ModelMap _modelMap;
@@ -17,6 +19,8 @@ class ModelCache :
 	// Flag to disable the cache on demand (used during clear())
 	bool _enabled;
 
+	sigc::signal<void> _sigModelsReloaded;
+
 public:
 	ModelCache();
 
@@ -26,19 +30,23 @@ public:
 	// greebo: For documentation, see the abstract base class.
 	IModelPtr getModel(const std::string& modelPath) override;
 
-	// Clears the cache
+	// Clear methods
+	void removeModel(const std::string& modelPath) override;
 	void clear() override;
 
-	// Command target: this reloads all models in the map
-	void refreshModels(const cmd::ArgumentList& args);
-	// Command target: this reloads all selected models in the map
-	void refreshSelectedModels(const cmd::ArgumentList& args);
+	// Public events
+	sigc::signal<void> signal_modelsReloaded() override;
 
 	// RegisterableModule implementation
 	const std::string& getName() const override;
 	const StringSet& getDependencies() const override;
 	void initialiseModule(const ApplicationContext& ctx) override;
 	void shutdownModule() override;
+
+private:
+	// Command targets
+	void refreshModels(const cmd::ArgumentList& args);
+	void refreshSelectedModels(const cmd::ArgumentList& args);
 };
 
 } // namespace model
