@@ -15,7 +15,6 @@
 #include "brush/TextureProjection.h"
 #include "brush/Winding.h"
 #include "wxutil/dialog/MessageBox.h"
-#include "ui/surfaceinspector/SurfaceInspector.h"
 #include "ui/patch/PatchInspector.h"
 #include "selection/algorithm/Shader.h"
 
@@ -52,8 +51,7 @@ inline bool double_valid(double f) {
 // Constructor
 Patch::Patch(PatchNode& node) :
 	_node(node),
-	_shader(texdef_name_default()),
-	_undoStateSaver(NULL),
+	_undoStateSaver(nullptr),
 	_solidRenderable(_mesh),
 	_wireframeRenderable(_mesh),
 	_fixedWireframeRenderable(_mesh),
@@ -61,7 +59,8 @@ Patch::Patch(PatchNode& node) :
 	_renderableCtrlPoints(GL_POINTS, _ctrl_vertices),
 	_renderableLattice(GL_LINES, _latticeIndices, _ctrl_vertices),
 	_transformChanged(false),
-	_tesselationChanged(true)
+	_tesselationChanged(true),
+	_shader(texdef_name_default())
 {
 	construct();
 }
@@ -73,8 +72,7 @@ Patch::Patch(const Patch& other, PatchNode& node) :
 	Snappable(other),
 	IUndoable(other),
 	_node(node),
-	_shader(other._shader.getMaterialName()),
-	_undoStateSaver(NULL),
+	_undoStateSaver(nullptr),
 	_solidRenderable(_mesh),
 	_wireframeRenderable(_mesh),
 	_fixedWireframeRenderable(_mesh),
@@ -82,7 +80,8 @@ Patch::Patch(const Patch& other, PatchNode& node) :
 	_renderableCtrlPoints(GL_POINTS, _ctrl_vertices),
 	_renderableLattice(GL_LINES, _latticeIndices, _ctrl_vertices),
 	_transformChanged(false),
-	_tesselationChanged(true)
+	_tesselationChanged(true),
+	_shader(other._shader.getMaterialName())
 {
 	// Initalise the default values
 	construct();
@@ -288,7 +287,7 @@ void Patch::testSelect(Selector& selector, SelectionTest& test)
 		pIndex += _mesh.lenStrips;
 	}
 
-	if (best.valid()) {
+	if (best.isValid()) {
 		selector.addIntersection(best);
 	}
 }
@@ -1925,8 +1924,8 @@ void Patch::constructPlane(const AABB& aabb, int axis, std::size_t width, std::s
   vStart[y] = aabb.origin[y] - aabb.extents[y];
   vStart[z] = aabb.origin[z];
 
-  float xAdj = fabsf((vStart[x] - (aabb.origin[x] + aabb.extents[x])) / (float)(_width - 1));
-  float yAdj = fabsf((vStart[y] - (aabb.origin[y] + aabb.extents[y])) / (float)(_height - 1));
+  float xAdj = std::abs((vStart[x] - (aabb.origin[x] + aabb.extents[x])) / (float)(_width - 1));
+  float yAdj = std::abs((vStart[y] - (aabb.origin[y] + aabb.extents[y])) / (float)(_height - 1));
 
   Vector3 vTmp;
   vTmp[z] = vStart[z];
@@ -2755,7 +2754,7 @@ void Patch::textureChanged()
 		(*i++)->onPatchTextureChanged();
 	}
 
-	ui::SurfaceInspector::update(); // Triggers TexTool and PatchInspector update
+	signal_patchTextureChanged().emit();
 }
 
 void Patch::attachObserver(Observer* observer)
@@ -2767,3 +2766,9 @@ void Patch::detachObserver(Observer* observer)
 {
 	_observers.erase(observer);
 }
+
+sigc::signal<void>& Patch::signal_patchTextureChanged()
+{
+	static sigc::signal<void> _sigPatchTextureChanged;
+	return _sigPatchTextureChanged;
+}
