@@ -1,6 +1,8 @@
 #include "GLSLDepthFillProgram.h"
 #include "render/backend/GLProgramFactory.h"
 
+#include "itextstream.h"
+
 namespace render
 {
 
@@ -14,7 +16,8 @@ namespace {
 void GLSLDepthFillProgram::create()
 {
     // Create the program object
-    std::cout << "[renderer] Creating GLSL depthfill program" << std::endl;
+    rConsole() << "[renderer] Creating GLSL depthfill program" << std::endl;
+
     _programObj = GLProgramFactory::createGLSLProgram(
         DEPTHFILL_VP_FILENAME, DEPTHFILL_FP_FILENAME
     );
