@@ -1,5 +1,6 @@
 #include "SelectionMouseTools.h"
 
+#include "iscenegraph.h"
 #include "i18n.h"
 #include "iuimanager.h"
 #include "registry/registry.h"
@@ -83,7 +84,7 @@ DragSelectionMouseTool::Result DragSelectionMouseTool::onCancel(IInteractiveView
     _dragSelectionRect = selection::Rectangle();
 
     // Update the views
-    GlobalSelectionSystem().cancelMove();
+	SceneChangeNotify();
 
     return Result::Finished;
 }
