@@ -2,26 +2,8 @@
 
 #include "FaceItem.h"
 
-namespace textool {
-
-class FaceItemCreator :
-	public BrushVisitor
+namespace textool
 {
-	// The target vector
-	TexToolItemVec& _vector;
-public:
-	FaceItemCreator(TexToolItemVec& vector) :
-		_vector(vector)
-	{}
-
-	void visit(Face& face) const {
-		TexToolItemPtr faceItem(
-			new FaceItem(face)
-		);
-
-		_vector.push_back(faceItem);
-	}
-};
 
 // Constructor
 BrushItem::BrushItem(Brush& sourceBrush) :
@@ -29,7 +11,10 @@ BrushItem::BrushItem(Brush& sourceBrush) :
 {
 	// Visit all the brush faces with the FaceItemCreator
 	// that populates the _children vector
-	_sourceBrush.forEachFace(FaceItemCreator(_children));
+    _sourceBrush.forEachFace([&](Face& face)
+    {
+        _children.push_back(std::make_shared<FaceItem>(face));
+    });
 }
 
 void BrushItem::beginTransformation() {
