@@ -10,6 +10,7 @@
 
 #include "modulesystem/StaticModule.h"
 
+#include "ui/prefdialog/GameSetupDialog.h"
 #include "ui/layers/LayerOrthoContextMenuItem.h"
 #include "ui/layers/LayerControlDialog.h"
 #include "ui/overlay/OverlayDialog.h"
@@ -27,6 +28,7 @@
 #include "ui/mousetool/ToolMappingDialog.h"
 #include "ui/about/AboutDialog.h"
 #include "textool/TexTool.h"
+#include "modelexport/ExportAsModelDialog.h"
 
 namespace ui
 {
@@ -110,7 +112,7 @@ void UserInterfaceModule::registerUICommands()
 {
 	TexTool::registerCommands();
 
-	GlobalCommandSystem().addCommand("ProjectSettings", PrefDialog::ShowProjectSettings);
+	GlobalCommandSystem().addCommand("ProjectSettings", GameSetupDialog::Show);
 	GlobalCommandSystem().addCommand("Preferences", PrefDialog::ShowPrefDialog);
 
 	GlobalCommandSystem().addCommand("ToggleConsole", Console::toggle);
@@ -129,6 +131,7 @@ void UserInterfaceModule::registerUICommands()
 	GlobalCommandSystem().addCommand("FindReplaceTextures", FindAndReplaceShader::ShowDialog);
 	GlobalCommandSystem().addCommand("ShowCommandList", CommandList::ShowDialog);
 	GlobalCommandSystem().addCommand("About", AboutDialog::showDialog);
+	GlobalCommandSystem().addCommand("ExportSelectedAsModelDialog", ExportAsModelDialog::ShowDialog);
 
 	// ----------------------- Bind Events ---------------------------------------
 
@@ -153,6 +156,7 @@ void UserInterfaceModule::registerUICommands()
 	GlobalEventManager().addCommand("FindReplaceTextures", "FindReplaceTextures");
 	GlobalEventManager().addCommand("ShowCommandList", "ShowCommandList");
 	GlobalEventManager().addCommand("About", "About");
+	GlobalEventManager().addCommand("ExportSelectedAsModelDialog", "ExportSelectedAsModelDialog");
 }
 
 // Static module registration
