@@ -13,7 +13,7 @@ MapPreview::MapPreview(wxWindow* parent) :
 	RenderPreview(parent)
 {}
 
-void MapPreview::setRootNode(const scene::INodePtr& root)
+void MapPreview::setRootNode(const scene::IMapRootNodePtr& root)
 {
 	getScene()->setRoot(root);
 
@@ -25,14 +25,18 @@ void MapPreview::setRootNode(const scene::INodePtr& root)
 		// Trigger an initial update of the subgraph
 		GlobalFilterSystem().updateSubgraph(getScene()->root());
 
-		// Calculate camera distance so map is appropriately zoomed
-		_camDist = -(getScene()->root()->worldAABB().getRadius() * 2.0f);
+        // Reset the model rotation
+        resetModelRotation();
 
-		_rotation = Matrix4::getIdentity();
+		// Calculate camera distance so map is appropriately zoomed
+        double distance = getScene()->root()->worldAABB().getRadius() * 2.0f;
+
+        setViewOrigin(Vector3(1, 1, 1) * distance);
+        setViewAngles(Vector3(34, 135, 0));
 	}
 }
 
-scene::INodePtr MapPreview::getRootNode()
+scene::IMapRootNodePtr MapPreview::getRootNode()
 {
 	return getScene()->root();
 }
