@@ -38,7 +38,7 @@ public:
     }
 
 private:
-    void onBrowseButtonClick();
+    void onBrowseButtonClick() override;
 };
 
 }
