@@ -11,9 +11,8 @@
 #include <wx/sizer.h>
 #include <wx/button.h>
 
-#include <boost/algorithm/string/split.hpp>
-#include <boost/algorithm/string/classification.hpp>
-#include <boost/lexical_cast.hpp>
+#include "string/split.h"
+#include "string/convert.h"
 
 namespace ui
 {
@@ -39,7 +38,7 @@ FloatPropertyEditor::FloatPropertyEditor(wxWindow* parent, Entity* entity,
 
 	// Split the options string to get min and max values
 	std::vector<std::string> values;
-	boost::algorithm::split(values, options, boost::algorithm::is_any_of(","));
+	string::split(values, options, ",");
 	if (values.size() != 2)
 		return;
 
@@ -47,10 +46,10 @@ FloatPropertyEditor::FloatPropertyEditor(wxWindow* parent, Entity* entity,
 	float min, max;
 	try
 	{
-		min = boost::lexical_cast<float>(values[0]);
-		max = boost::lexical_cast<float>(values[1]);
+		min = std::stof(values[0]);
+		max = std::stof(values[1]);
 	}
-	catch (boost::bad_lexical_cast&)
+	catch (std::invalid_argument&)
 	{
 		rError() << "[radiant] FloatPropertyEditor failed to parse options string "
 			<< "\"" << options << "\"" << std::endl;
@@ -79,14 +78,8 @@ void FloatPropertyEditor::updateFromEntity()
 {
 	if (_spinCtrl == nullptr) return;
 
-	float value = 0;
-
-	try
-	{
-		value = boost::lexical_cast<float>(_entity->getKeyValue(_key));
-	}
-	catch (boost::bad_lexical_cast&) {}
-
+	float value = string::convert<float>(_entity->getKeyValue(_key), 0);
+	
 	_spinCtrl->SetValue(value);
 }
 
@@ -94,7 +87,7 @@ void FloatPropertyEditor::_onApply(wxCommandEvent& ev)
 {
 	float value = static_cast<float>(_spinCtrl->GetValue());
 
-	setKeyValue(_key, boost::lexical_cast<std::string>(value));
+	setKeyValue(_key, string::to_string(value));
 }
 
 }
