@@ -1,15 +1,15 @@
 #pragma once
 
 #include <functional>
+#include <map>
+#include <memory>
 
 #include <wx/menu.h>
-#include "layers/LayerSystem.h"
 
 namespace ui 
 {
 
 class LayerContextMenu :
-	public scene::LayerSystem::Visitor,
 	public wxMenu
 {
 public:
