@@ -5,6 +5,7 @@
 #include "ieventmanager.h"
 #include "ilayer.h"
 #include "imainframe.h"
+#include "iselection.h"
 
 #include "registry/registry.h"
 
@@ -15,8 +16,10 @@
 #include <wx/panel.h>
 #include <wx/artprov.h>
 #include <wx/scrolwin.h>
+#include <functional>
 
 #include "layers/LayerSystem.h"
+#include "layers/LayerUsageBreakdown.h"
 
 namespace ui
 {
@@ -29,13 +32,16 @@ namespace
 
 LayerControlDialog::LayerControlDialog() :
 	TransientWindow(_("Layers"), GlobalMainFrame().getWxTopLevelWindow(), true),
-	_dialogPanel(NULL),
-	_controlContainer(NULL),
-	_showAllLayers(NULL),
-	_hideAllLayers(NULL)
+	_dialogPanel(nullptr),
+	_controlContainer(nullptr),
+	_showAllLayers(nullptr),
+	_hideAllLayers(nullptr),
+	_rescanSelectionOnIdle(false)
 {
 	populateWindow();
 
+	Bind(wxEVT_IDLE, [&](wxIdleEvent&) { onIdle(); });
+
 	InitialiseWindowPosition(230, 400, RKEY_WINDOW_STATE);
     SetMinClientSize(wxSize(230, 200));
 }
@@ -49,8 +55,8 @@ void LayerControlDialog::populateWindow()
 	
 	_dialogPanel->SetSizer(new wxBoxSizer(wxVERTICAL));
 
-	_controlContainer = new wxFlexGridSizer(1, 3, 3, 3);
-	_controlContainer->AddGrowableCol(1);
+	_controlContainer = new wxFlexGridSizer(1, 4, 3, 3);
+	_controlContainer->AddGrowableCol(2);
 
     _dialogPanel->GetSizer()->Add(_controlContainer, 1, wxEXPAND | wxTOP | wxLEFT | wxRIGHT, 12);
 
@@ -104,7 +110,7 @@ void LayerControlDialog::refresh()
     {
         // Create a new layercontrol for each visited layer
         // Store the object in a sorted container
-        sortedControls[layerName] = LayerControlPtr(new LayerControl(_dialogPanel, layerID));
+        sortedControls[layerName] = std::make_shared<LayerControl>(_dialogPanel, layerID);
     });
 
     // Assign all controls to the target vector, alphabetically sorted
@@ -115,19 +121,18 @@ void LayerControlDialog::refresh()
 
 	_controlContainer->SetRows(static_cast<int>(_layerControls.size()));
 
-	int c = 0;
-	for (LayerControls::iterator i = _layerControls.begin();
-		 i != _layerControls.end(); ++i, ++c)
+	for (const LayerControlPtr& control : _layerControls)
 	{
-		_controlContainer->Add((*i)->getToggle(), 0);
-		_controlContainer->Add((*i)->getLabelButton(), 0, wxEXPAND);
-		_controlContainer->Add((*i)->getButtons(), 0, wxEXPAND);
+		_controlContainer->Add(control->getToggle(), 0);
+		_controlContainer->Add(control->getStatusWidget(), 0, wxEXPAND | wxTOP | wxBOTTOM, 1);
+		_controlContainer->Add(control->getLabelButton(), 0, wxEXPAND);
+		_controlContainer->Add(control->getButtons(), 0, wxEXPAND);
 
-        if (c == 0)
+        if (control == _layerControls.front())
         {
             // Prevent setting the focus on the buttons at the bottom which lets the scrollbar 
             // of the window jump around (#4089), set the focus on the first button.
-            (*i)->getLabelButton()->SetFocus();
+			control->getLabelButton()->SetFocus();
         }
 	}
 
@@ -140,15 +145,17 @@ void LayerControlDialog::refresh()
 void LayerControlDialog::update()
 {
 	// Broadcast the update() call
-	for (LayerControls::iterator i = _layerControls.begin();
-		 i != _layerControls.end(); ++i)
+	for (const LayerControlPtr& control : _layerControls)
 	{
-		(*i)->update();
+		control->update();
 	}
 
+	// Update usage next time round
+	_rescanSelectionOnIdle = true;
+
 	// Update the show/hide all button sensitiveness
-    std::size_t numVisible;
-    std::size_t numHidden;
+    std::size_t numVisible = 0;
+    std::size_t numHidden = 0;
 
     GlobalLayerSystem().foreachLayer([&](int layerID, const std::string& layerName)
     {
@@ -166,12 +173,34 @@ void LayerControlDialog::update()
 	_hideAllLayers->Enable(numVisible > 0);
 }
 
+void LayerControlDialog::updateLayerUsage()
+{
+	_rescanSelectionOnIdle = false;
+
+	// Scan the selection and get the histogram
+	scene::LayerUsageBreakdown breakDown = scene::LayerUsageBreakdown::CreateFromSelection();
+
+	for (const LayerControlPtr& control : _layerControls)
+	{
+		assert(static_cast<int>(breakDown.size()) > control->getLayerId());
+
+		control->updateUsageStatusWidget(breakDown[control->getLayerId()]);
+	}
+}
+
+void LayerControlDialog::onIdle()
+{
+	if (!_rescanSelectionOnIdle) return;
+
+	updateLayerUsage();
+}
+
 void LayerControlDialog::toggle(const cmd::ArgumentList& args)
 {
 	Instance().ToggleVisibility();
 }
 
-void LayerControlDialog::init()
+void LayerControlDialog::onRadiantStartup()
 {
 	// Lookup the stored window information in the registry
 	if (GlobalRegistry().getAttribute(RKEY_WINDOW_STATE, "visible") == "1")
@@ -211,15 +240,14 @@ LayerControlDialog& LayerControlDialog::Instance()
 {
 	LayerControlDialogPtr& instancePtr = InstancePtr();
 
-	if (instancePtr == NULL)
+	if (!instancePtr)
 	{
 		// Not yet instantiated, do it now
 		instancePtr.reset(new LayerControlDialog);
 
 		// Register this instance with GlobalRadiant() at once
 		GlobalRadiant().signal_radiantShutdown().connect(
-            sigc::mem_fun(*instancePtr, &LayerControlDialog::onRadiantShutdown)
-        );
+            sigc::mem_fun(*instancePtr, &LayerControlDialog::onRadiantShutdown));
 	}
 
 	return *instancePtr;
@@ -230,10 +258,43 @@ void LayerControlDialog::_preShow()
 {
 	TransientWindow::_preShow();
 
+	_selectionChangedSignal = GlobalSelectionSystem().signal_selectionChanged().connect([this](const ISelectable&)
+	{
+		_rescanSelectionOnIdle = true;
+	});
+
+	// Layer creation/addition/removal triggers a refresh
+	_layersChangedSignal = GlobalLayerSystem().signal_layersChanged().connect(
+		sigc::mem_fun(this, &LayerControlDialog::refresh));
+
+	// Visibility change doesn't repopulate the dialog
+	_layerVisibilityChangedSignal = GlobalLayerSystem().signal_layerVisibilityChanged().connect(
+		sigc::mem_fun(this, &LayerControlDialog::update));
+
+	// Node membership triggers a selection rescan
+	_nodeLayerMembershipChangedSignal = GlobalLayerSystem().signal_nodeMembershipChanged().connect([this]()
+	{
+		_rescanSelectionOnIdle = true;
+	});
+
+	_mapEventSignal = GlobalMapModule().signal_mapEvent().connect(
+		sigc::mem_fun(this, &LayerControlDialog::onMapEvent)
+	);
+
 	// Re-populate the dialog
 	refresh();
 }
 
+void LayerControlDialog::_postHide()
+{
+	_mapEventSignal.disconnect();
+	_nodeLayerMembershipChangedSignal.disconnect();
+	_layersChangedSignal.disconnect();
+	_layerVisibilityChangedSignal.disconnect();
+	_selectionChangedSignal.disconnect();
+	_rescanSelectionOnIdle = false;
+}
+
 void LayerControlDialog::onShowAllLayers(wxCommandEvent& ev)
 {
     GlobalLayerSystem().foreachLayer([&](int layerID, const std::string& layerName)
@@ -250,4 +311,13 @@ void LayerControlDialog::onHideAllLayers(wxCommandEvent& ev)
     });
 }
 
+void LayerControlDialog::onMapEvent(IMap::MapEvent ev)
+{
+	if (ev == IMap::MapLoaded)
+	{
+		// Rebuild the dialog once a map is loaded
+		refresh();
+	}
+}
+
 } // namespace ui
