@@ -1,5 +1,6 @@
 #pragma once
 
+#include "imap.h"
 #include "iradiant.h"
 #include "icommandsystem.h"
 #include "wxutil/window/TransientWindow.h"
@@ -7,6 +8,7 @@
 
 #include <wx/panel.h>
 #include <memory>
+#include <sigc++/connection.h>
 
 class wxButton;
 class wxFlexGridSizer;
@@ -33,6 +35,13 @@ private:
 	wxButton* _showAllLayers;
 	wxButton* _hideAllLayers;
 
+	bool _rescanSelectionOnIdle;
+	sigc::connection _selectionChangedSignal;
+	sigc::connection _layersChangedSignal;
+	sigc::connection _layerVisibilityChangedSignal;
+	sigc::connection _nodeLayerMembershipChangedSignal;
+	sigc::connection _mapEventSignal;
+
 public:
 	LayerControlDialog();
 
@@ -47,8 +56,8 @@ public:
 	// Command target (registered in the event manager)
 	static void toggle(const cmd::ArgumentList& args);
 
-	// Called during mainframe construction
-	static void init();
+	// Checks if dialog should be shown after startup
+	static void onRadiantStartup();
 
 	static LayerControlDialog& Instance();
 
@@ -56,15 +65,22 @@ private:
 	static LayerControlDialogPtr& InstancePtr();
 
 	// TransientWindow events
-	void _preShow();
+	void _preShow() override;
+	void _postHide() override;
 
 	void populateWindow();
 
+	// Update the usage colours on the controls
+	void updateLayerUsage();
+
 	// Creates the option buttons
 	void createButtons();
 
 	void onShowAllLayers(wxCommandEvent& ev);
 	void onHideAllLayers(wxCommandEvent& ev);
+	void onIdle();
+
+	void onMapEvent(IMap::MapEvent ev);
 };
 
 } // namespace ui
