@@ -27,10 +27,8 @@
 #include "PrefabPopulator.h"
 #include "map/algorithm/WorldspawnArgFinder.h"
 
-#include <boost/algorithm/string/split.hpp>
-#include <boost/algorithm/string/trim.hpp>
-#include <boost/algorithm/string/case_conv.hpp>
-#include <boost/lexical_cast.hpp>
+#include "string/trim.h"
+#include "string/case_conv.h"
 #include <functional>
 
 namespace ui
@@ -208,8 +206,8 @@ void PrefabSelector::setupPathSelector(wxSizer* parentSizer)
 
 void PrefabSelector::addCustomPathToRecentList()
 {
-    std::string customPath = boost::algorithm::to_lower_copy(_customPath->getValue());
-    boost::algorithm::trim(customPath);
+    std::string customPath = string::to_lower_copy(_customPath->getValue());
+    string::trim(customPath);
 
     if (customPath.empty())
     {
