@@ -9,9 +9,9 @@
 
 #include <wx/sizer.h>
 #include <wx/treebook.h>
-#include <boost/algorithm/string/split.hpp>
-#include <boost/algorithm/string/classification.hpp>
-#include <boost/algorithm/string/join.hpp>
+#include "string/split.h"
+#include "string/join.h"
+#include "string/predicate.h"
 
 #include "settings/PreferenceSystem.h"
 #include "settings/PreferencePage.h"
@@ -57,12 +57,12 @@ void PrefDialog::createPages()
 		_pages[pagePath] = pageWidget;
 
 		std::vector<std::string> parts;
-		boost::algorithm::split(parts, pagePath, boost::algorithm::is_any_of("/"));
+		string::split(parts, pagePath, "/");
 
 		if (parts.size() > 1)
 		{
 			parts.pop_back();
-			std::string parentPath = boost::algorithm::join(parts, "/");
+			std::string parentPath = string::join(parts, "/");
 			
 			PageMap::const_iterator parent = _pages.find(parentPath);
 
@@ -108,6 +108,19 @@ void PrefDialog::showModal(const std::string& requestedPage)
 	{
 		showPage(requestedPage);
 	}
+	else
+	{
+		// To prevent starting up with the "Game" node selected, 
+		// select the first page below the Settings path
+		for (const PageMap::value_type& p : _pages)
+		{
+			if (string::starts_with(p.first, _("Settings/")))
+			{
+				showPage(p.first);
+				break;
+			}
+		}
+	}
 
 	if (ShowModal() == wxID_OK)
 	{
