@@ -7,7 +7,8 @@
 #include "texturelib.h"
 #include "wxutil/menu/PopupMenu.h"
 
-#include <wx/event.h>
+#include "TextureBrowserManager.h"
+#include <wx/panel.h>
 
 namespace wxutil
 {
@@ -19,10 +20,19 @@ class wxScrollBar;
 class wxScrollEvent;
 class wxToolBar;
 
-namespace ui {
+namespace ui 
+{
 
-class TextureBrowser;
-typedef std::shared_ptr<TextureBrowser> TextureBrowserPtr;
+namespace
+{
+    const char* const RKEY_TEXTURES_HIDE_UNUSED = "user/ui/textures/browser/hideUnused";
+    const char* const RKEY_TEXTURE_UNIFORM_SIZE = "user/ui/textures/browser/uniformSize";
+    const char* const RKEY_TEXTURE_SHOW_SCROLLBAR = "user/ui/textures/browser/showScrollBar";
+    const char* const RKEY_TEXTURE_MOUSE_WHEEL_INCR = "user/ui/textures/browser/mouseWheelIncrement";
+    const char* const RKEY_TEXTURE_SHOW_FILTER = "user/ui/textures/browser/showFilter";
+    const char* const RKEY_TEXTURE_CONTEXTMENU_EPSILON = "user/ui/textures/browser/contextMenuMouseEpsilon";
+    const char* const RKEY_TEXTURE_MAX_NAME_LENGTH = "user/ui/textures/browser/maxShadernameLength";
+}
 
 /**
  * \brief
@@ -32,13 +42,15 @@ typedef std::shared_ptr<TextureBrowser> TextureBrowserPtr;
  * containing all active texture tiles.
  */
 class TextureBrowser :
-    public sigc::trackable,
-	public wxEvtHandler,
-    public MaterialManager::ActiveShadersObserver,
-    public std::enable_shared_from_this<TextureBrowser>
+    public wxPanel,
+    public sigc::trackable
 {
     typedef BasicVector2<int> Vector2i;
 
+    class TextureTile;
+    typedef std::list<TextureTile> TextureTiles;
+    TextureTiles _tiles;
+
     // Size of the 2D viewport. This is the geometry of the render window, not
     // the entire virtual space.
     Vector2i _viewportSize;
@@ -84,7 +96,7 @@ class TextureBrowser :
     
     // the increment step we use against the wheel mouse
     std::size_t _mouseWheelScrollIncrement;
-    std::size_t _textureScale;
+
     bool _showTextureFilter;
     // make the texture increments match the grid changes
     bool _showTextureScrollbar;
@@ -92,38 +104,27 @@ class TextureBrowser :
     // if false, all the shaders in memory are displayed
     bool _hideUnused;
     
-    // If true, textures are resized to a uniform size when displayed in the texture browser.
-    // If false, textures are displayed in proportion to their pixel size.
-    bool _resizeTextures;
     // The uniform size (in pixels) that textures are resized to when m_resizeTextures is true.
     int _uniformTextureSize;
 
+    unsigned int _maxNameLength;
+
 	wxToolBar* _textureToolbar;
+
+    // renderable items will be updated next round
+    bool _updateNeeded;
     
 public:
     // Constructor
-    TextureBrowser();
+    TextureBrowser(wxWindow* parent);
 
-    // Triggers a refresh
-    void update();
+    virtual ~TextureBrowser();
 
-    void clearFilter();
-
-    int getViewportHeight();
-
-    /**
-     * greebo: Constructs the TextureBrowser window and retrieves the
-     * widget for packing into the GroupDialog for instance.
-     */
-	wxWindow* constructWindow(wxWindow* parent);
-
-    void destroyWindow();
+    // Schedules an update of the renderable items
+    void queueUpdate();
 
     void queueDraw();
 
-    // Callback needed for DeferredAdjustment
-    void scrollChanged(double value);
-
     /** greebo: Returns the currently selected shader
      */
     const std::string& getSelectedShader() const;
@@ -133,29 +134,19 @@ public:
      */
     void setSelectedShader(const std::string& newShader);
 
-    /** greebo: This toggles the display of the TextureBrowser,
-     *          basically passes the call to the GroupDialog instance,
-     *          which takes care of the details.
-     *
-     * Note: This is a command target, hence the static
-     */
-    static void toggle(const cmd::ArgumentList& args);
-
-    /** greebo: Adds the according options to the Preferences dialog.
-     */
-    static void registerPreferencesPage();
-
-    static void construct();
-    static void destroy();
-
-    // Accessor to the singleton
-    static TextureBrowser& Instance();
-
-	// This gets called by the ShaderSystem
-    void onActiveShadersChanged();
-
 private:
-    static TextureBrowserPtr& InstancePtr();
+    void clearFilter();
+
+    int getViewportHeight();
+
+    // Callback needed for DeferredAdjustment
+    void scrollChanged(double value);
+
+    // Actually updates the renderable items (usually done before rendering)
+    void performUpdate();
+
+    // This gets called by the ShaderSystem
+    void onActiveShadersChanged();
 
     // Return the display width/height of a texture in the texture browser
     int getTextureWidth(const Texture& tex) const;
@@ -173,14 +164,9 @@ private:
     // Displays the context menu
     void openContextMenu();
 
-    // greebo: This gets called as soon as the texture mode gets changed
-    void textureModeChanged();
-
     void observeKey(const std::string& key);
     void keyChanged();
 
-    void setScaleFromRegistry();
-
     /** greebo: The actual drawing method invoking the GL calls.
      */
     void draw();
@@ -189,8 +175,6 @@ private:
      */
     void doMouseWheel(bool wheelUp);
 
-    void heightChanged();
-
     void updateScroll();
 
     /** greebo: Returns the currently active filter string or "" if
@@ -208,8 +192,6 @@ private:
      */
     void focus(const std::string& name);
 
-    void evaluateHeight();
-
     /** greebo: Returns the total height of the GL content
      */
     int getTotalHeight();
@@ -219,11 +201,13 @@ private:
     int getOriginY();
     void setOriginY(int newOriginY);
 
-    /** greebo: Returns the shader at the given coords.
-     *
+    /** 
+     * greebo: Returns the shader at the given coords.
+     * The coords are window coords, not the virtual coords
+     * which span the entire scrollable area.
      * @returns: the MaterialPtr, which may be empty.
      */
-    MaterialPtr getShaderAtCoords(int mx, int my);
+    MaterialPtr getShaderAtCoords(int x, int y);
 
     /** greebo: Tries to select the shader at the given coords.
      *          When successful, this applies the shader to the
@@ -231,12 +215,13 @@ private:
      */
     void selectTextureAt(int mx, int my);
 
-    /** greebo: Returns true if the given <shader> is visible,
-     *          taking filter and showUnused into account.
+    /** greebo: Returns true if the given material is visible,
+     * taking filter and showUnused into account.
      */
-    bool shaderIsVisible(const MaterialPtr& shader);
+    bool materialIsVisible(const MaterialPtr& material);
 
 	// wx callbacks
+    void onIdle(wxIdleEvent& ev);
 	void onRender();
 	void onScrollChanged(wxScrollEvent& ev);
 	void onGLResize(wxSizeEvent& ev);
@@ -252,4 +237,4 @@ private:
 } // namespace ui
 
 // Accessor method to the singleton instance
-ui::TextureBrowser& GlobalTextureBrowser();
+ui::TextureBrowserManager& GlobalTextureBrowser();
