@@ -128,7 +128,7 @@ MouseTool::Result BrushCreatorTool::onMouseUp(Event& ev)
     try
     {
         // We only operate on XY view events, so attempt to cast
-        dynamic_cast<XYMouseToolEvent&>(ev);
+        dynamic_cast<XYMouseToolEvent&>(ev).getScale();
 
         GlobalUndoSystem().finish("brushDragNew");
 
